@@ -1,6 +1,6 @@
 //go:build windows
 
-//go:generate goversioninfo -icon=../../assets/windows/tiger.ico
+//go:generate ../../scripts/windows-gen-syso.sh $GOARCH
 
 package main
 
@@ -10,6 +10,7 @@ import (
 
 	"github.com/kardianos/service"
 	"github.com/urfave/cli/v2"
+	"golang.org/x/sys/windows"
 
 	"github.com/influxdata/telegraf/logger"
 )
@@ -45,6 +46,16 @@ func cliFlags() []cli.Flag {
 	}
 }
 
+func getLockedMemoryLimit() uint64 {
+	handle := windows.CurrentProcess()
+
+	var min, max uintptr
+	var flag uint32
+	windows.GetProcessWorkingSetSizeEx(handle, &min, &max, &flag)
+
+	return uint64(max)
+}
+
 func (t *Telegraf) Run() error {
 	// Register the eventlog logging target for windows.
 	err := logger.RegisterEventLogger(t.serviceName)
