@@ -5,6 +5,7 @@ package logger
 import (
 	"bytes"
 	"encoding/xml"
+	"fmt"
 	"log"
 	"os/exec"
 	"testing"
@@ -30,7 +31,12 @@ type Event struct {
 func getEventLog(t *testing.T, since time.Time) []Event {
 	timeStr := since.UTC().Format(time.RFC3339)
 	timeStr = timeStr[:19]
-	cmd := exec.Command("wevtutil", "qe", "Application", "/rd:true", "/q:Event[System[TimeCreated[@SystemTime >= '"+timeStr+"'] and Provider[@Name='telegraf']]]")
+	args := []string{
+		"qe",
+		"Application",
+		"/rd:true",
+		fmt.Sprintf("/q:Event[System[TimeCreated[@SystemTime >= %q] and Provider[@Name='telegraf']]]", timeStr)}
+	cmd := exec.Command("wevtutil", args...)
 	var out bytes.Buffer
 	cmd.Stdout = &out
 	err := cmd.Run()
