@@ -153,7 +153,7 @@ func (b *Bind) readStatsXMLv3(addr *url.URL, acc telegraf.Accumulator) error {
 			}
 
 			if err := xml.NewDecoder(resp.Body).Decode(&stats); err != nil {
-				return fmt.Errorf("unable to decode XML document: %s", err)
+				return fmt.Errorf("unable to decode XML document: %w", err)
 			}
 
 			return nil
