@@ -14,12 +14,20 @@ var sampleConfig string
 type CGroup struct {
 	Paths []string `toml:"paths"`
 	Files []string `toml:"files"`
+
+	logged map[string]bool
 }
 
 func (*CGroup) SampleConfig() string {
 	return sampleConfig
 }
 
+func (cg *CGroup) Init() error {
+	cg.logged = make(map[string]bool)
+
+	return nil
+}
+
 func init() {
 	inputs.Add("cgroup", func() telegraf.Input { return &CGroup{} })
 }
