@@ -3,6 +3,7 @@
 package execd
 
 import (
+	"errors"
 	"fmt"
 	"io"
 	"os"
@@ -19,10 +20,14 @@ func (e *Execd) Gather(acc telegraf.Accumulator) error {
 	switch e.Signal {
 	case "STDIN":
 		if osStdin, ok := e.process.Stdin.(*os.File); ok {
-			osStdin.SetWriteDeadline(time.Now().Add(1 * time.Second))
+			if err := osStdin.SetWriteDeadline(time.Now().Add(1 * time.Second)); err != nil {
+				if !errors.Is(err, os.ErrNoDeadline) {
+					return fmt.Errorf("setting write deadline failed: %w", err)
+				}
+			}
 		}
 		if _, err := io.WriteString(e.process.Stdin, "\n"); err != nil {
-			return fmt.Errorf("Error writing to stdin: %s", err)
+			return fmt.Errorf("error writing to stdin: %w", err)
 		}
 	case "none":
 	default:
