@@ -30,7 +30,9 @@ var sampleConfig string
 const (
 	// defaultMaxBodySize is the default maximum request body size, in bytes.
 	// if the request body is over this size, we will return an HTTP 413 error.
-	defaultMaxBodySize = 32 * 1024 * 1024
+	defaultMaxBodySize  = 32 * 1024 * 1024
+	defaultReadTimeout  = 10 * time.Second
+	defaultWriteTimeout = 10 * time.Second
 )
 
 var ErrEOF = errors.New("EOF")
@@ -49,10 +51,12 @@ type InfluxDBV2Listener struct {
 	port           int
 	tlsint.ServerConfig
 
-	MaxBodySize config.Size `toml:"max_body_size"`
-	Token       string      `toml:"token"`
-	BucketTag   string      `toml:"bucket_tag"`
-	ParserType  string      `toml:"parser_type"`
+	ReadTimeout  config.Duration `toml:"read_timeout"`
+	WriteTimeout config.Duration `toml:"write_timeout"`
+	MaxBodySize  config.Size     `toml:"max_body_size"`
+	Token        string          `toml:"token"`
+	BucketTag    string          `toml:"bucket_tag"`
+	ParserType   string          `toml:"parser_type"`
 
 	timeFunc influx.TimeFunc
 
@@ -117,6 +121,13 @@ func (h *InfluxDBV2Listener) Init() error {
 		h.MaxBodySize = config.Size(defaultMaxBodySize)
 	}
 
+	if h.ReadTimeout < config.Duration(time.Second) {
+		h.ReadTimeout = config.Duration(defaultReadTimeout)
+	}
+	if h.WriteTimeout < config.Duration(time.Second) {
+		h.WriteTimeout = config.Duration(defaultWriteTimeout)
+	}
+
 	return nil
 }
 
@@ -130,9 +141,11 @@ func (h *InfluxDBV2Listener) Start(acc telegraf.Accumulator) error {
 	}
 
 	h.server = http.Server{
-		Addr:      h.ServiceAddress,
-		Handler:   h,
-		TLSConfig: tlsConf,
+		Addr:         h.ServiceAddress,
+		Handler:      h,
+		TLSConfig:    tlsConf,
+		ReadTimeout:  time.Duration(h.ReadTimeout),
+		WriteTimeout: time.Duration(h.WriteTimeout),
 	}
 
 	var listener net.Listener
