@@ -44,13 +44,13 @@ func TestJobRequest(t *testing.T) {
 	}
 	for _, test := range tests {
 		hierarchyName := test.input.hierarchyName()
-		URL := test.input.URL()
+		address := test.input.URL()
 		if hierarchyName != test.hierarchyName {
 			t.Errorf("Expected %s, got %s\n", test.hierarchyName, hierarchyName)
 		}
 
-		if test.URL != "" && URL != test.URL {
-			t.Errorf("Expected %s, got %s\n", test.URL, URL)
+		if test.URL != "" && address != test.URL {
+			t.Errorf("Expected %s, got %s\n", test.URL, address)
 		}
 	}
 }
@@ -97,9 +97,8 @@ func (h mockHandler) ServeHTTP(w http.ResponseWriter, r *http.Request) {
 		w.WriteHeader(http.StatusNoContent)
 		return
 	}
-	// Ignore the returned error as the tests will fail anyway
-	//nolint:errcheck,revive
-	w.Write(b)
+
+	w.Write(b) //nolint:errcheck // ignore the returned error as the tests will fail anyway
 }
 
 func TestGatherNodeData(t *testing.T) {
@@ -156,7 +155,7 @@ func TestGatherNodeData(t *testing.T) {
 			},
 		},
 		{
-			name: "filtered nodes",
+			name: "filtered nodes (excluded)",
 			input: mockHandler{
 				responseMap: map[string]interface{}{
 					"/api/json": struct{}{},
@@ -184,6 +183,35 @@ func TestGatherNodeData(t *testing.T) {
 				},
 			},
 		},
+		{
+			name: "filtered nodes (included)",
+			input: mockHandler{
+				responseMap: map[string]interface{}{
+					"/api/json": struct{}{},
+					"/computer/api/json": nodeResponse{
+						BusyExecutors:  4,
+						TotalExecutors: 8,
+						Computers: []node{
+							{DisplayName: "filtered-1"},
+							{DisplayName: "filtered-1"},
+						},
+					},
+				},
+			},
+			output: &testutil.Accumulator{
+				Metrics: []*testutil.Metric{
+					{
+						Tags: map[string]string{
+							"source": "127.0.0.1",
+						},
+						Fields: map[string]interface{}{
+							"busy_executors":  4,
+							"total_executors": 8,
+						},
+					},
+				},
+			},
+		},
 		{
 			name: "normal data collection",
 			input: mockHandler{
@@ -306,6 +334,7 @@ func TestGatherNodeData(t *testing.T) {
 				URL:             ts.URL,
 				ResponseTimeout: config.Duration(time.Microsecond),
 				NodeExclude:     []string{"ignore-1", "ignore-2"},
+				NodeInclude:     []string{"master", "slave"},
 			}
 			te := j.initialize(&http.Client{Transport: &http.Transport{}})
 			acc := new(testutil.Accumulator)
@@ -330,7 +359,8 @@ func TestGatherNodeData(t *testing.T) {
 					}
 					for k, m := range test.output.Metrics[i].Fields {
 						if acc.Metrics[i].Fields[k] != m {
-							t.Fatalf("%s: field %s metrics unmatch Expected %v(%T), got %v(%T)\n", test.name, k, m, m, acc.Metrics[0].Fields[k], acc.Metrics[0].Fields[k])
+							t.Fatalf("%s: field %s metrics unmatch Expected %v(%T), got %v(%T)\n",
+								test.name, k, m, m, acc.Metrics[0].Fields[k], acc.Metrics[0].Fields[k])
 						}
 					}
 				}
@@ -399,7 +429,7 @@ func TestInitialize(t *testing.T) {
 			}
 			if test.output != nil {
 				if test.input.client == nil {
-					t.Fatalf("%s: failed %s, jenkins instance shouldn't be nil", test.name, te.Error())
+					t.Fatalf("%s: failed %v, jenkins instance shouldn't be nil", test.name, te)
 				}
 				if test.input.MaxConnections != test.output.MaxConnections {
 					t.Fatalf("%s: different MaxConnections Expected %d, got %d\n", test.name, test.output.MaxConnections, test.input.MaxConnections)
@@ -844,7 +874,8 @@ func TestGatherJobs(t *testing.T) {
 					}
 					for k, m := range test.output.Metrics[i].Fields {
 						if acc.Metrics[i].Fields[k] != m {
-							t.Fatalf("%s: field %s metrics unmatch Expected %v(%T), got %v(%T)\n", test.name, k, m, m, acc.Metrics[i].Fields[k], acc.Metrics[0].Fields[k])
+							t.Fatalf("%s: field %s metrics unmatch Expected %v(%T), got %v(%T)\n",
+								test.name, k, m, m, acc.Metrics[i].Fields[k], acc.Metrics[0].Fields[k])
 						}
 					}
 				}
