@@ -6,16 +6,17 @@ import (
 	_ "embed"
 	"encoding/json"
 	"fmt"
-	v1 "k8s.io/api/core/v1"
-	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/client-go/kubernetes"
-	"k8s.io/client-go/rest"
 	"net/http"
 	"os"
 	"strings"
 	"sync"
 	"time"
 
+	v1 "k8s.io/api/core/v1"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/client-go/kubernetes"
+	"k8s.io/client-go/rest"
+
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/filter"
@@ -46,7 +47,7 @@ type Kubernetes struct {
 
 	Log telegraf.Logger `toml:"-"`
 
-	RoundTripper http.RoundTripper
+	httpClient *http.Client
 }
 
 const (
@@ -129,7 +130,7 @@ func getNodeURLs(log telegraf.Logger) ([]string, error) {
 	for _, n := range nodes.Items {
 		address := getNodeAddress(n)
 		if address == "" {
-			log.Warn("Unable to node addresses for Node '%s'", n.Name)
+			log.Warnf("Unable to node addresses for Node %q", n.Name)
 			continue
 		}
 		nodeUrls = append(nodeUrls, "https://"+address+":10250")
@@ -243,16 +244,22 @@ func (k *Kubernetes) LoadJSON(url string, v interface{}) error {
 	if err != nil {
 		return err
 	}
-	if k.RoundTripper == nil {
+
+	if k.httpClient == nil {
 		if k.ResponseTimeout < config.Duration(time.Second) {
 			k.ResponseTimeout = config.Duration(time.Second * 5)
 		}
-		k.RoundTripper = &http.Transport{
-			TLSHandshakeTimeout:   5 * time.Second,
-			TLSClientConfig:       tlsCfg,
-			ResponseHeaderTimeout: time.Duration(k.ResponseTimeout),
+		k.httpClient = &http.Client{
+			Transport: &http.Transport{
+				TLSClientConfig: tlsCfg,
+			},
+			CheckRedirect: func(req *http.Request, via []*http.Request) error {
+				return http.ErrUseLastResponse
+			},
+			Timeout: time.Duration(k.ResponseTimeout),
 		}
 	}
+
 	if k.BearerToken != "" {
 		token, err := os.ReadFile(k.BearerToken)
 		if err != nil {
@@ -262,9 +269,9 @@ func (k *Kubernetes) LoadJSON(url string, v interface{}) error {
 	}
 	req.Header.Set("Authorization", "Bearer "+k.BearerTokenString)
 	req.Header.Add("Accept", "application/json")
-	resp, err = k.RoundTripper.RoundTrip(req)
+	resp, err = k.httpClient.Do(req)
 	if err != nil {
-		return fmt.Errorf("error making HTTP request to %s: %s", url, err)
+		return fmt.Errorf("error making HTTP request to %q: %w", url, err)
 	}
 	defer resp.Body.Close()
 	if resp.StatusCode != http.StatusOK {
@@ -273,7 +280,7 @@ func (k *Kubernetes) LoadJSON(url string, v interface{}) error {
 
 	err = json.NewDecoder(resp.Body).Decode(v)
 	if err != nil {
-		return fmt.Errorf(`Error parsing response: %s`, err)
+		return fmt.Errorf("error parsing response: %w", err)
 	}
 
 	return nil
