@@ -23,7 +23,10 @@ var (
 )
 
 type LVM struct {
-	UseSudo bool `toml:"use_sudo"`
+	UseSudo   bool   `toml:"use_sudo"`
+	PVSBinary string `toml:"pvs_binary"`
+	VGSBinary string `toml:"vgs_binary"`
+	LVSBinary string `toml:"lvs_binary"`
 }
 
 func (*LVM) SampleConfig() string {
@@ -47,12 +50,11 @@ func (lvm *LVM) Gather(acc telegraf.Accumulator) error {
 }
 
 func (lvm *LVM) gatherPhysicalVolumes(acc telegraf.Accumulator) error {
-	pvsCmd := "/usr/sbin/pvs"
 	args := []string{
 		"--reportformat", "json", "--units", "b", "--nosuffix",
 		"-o", "pv_name,vg_name,pv_size,pv_free,pv_used",
 	}
-	out, err := lvm.runCmd(pvsCmd, args)
+	out, err := lvm.runCmd(lvm.PVSBinary, args)
 	if err != nil {
 		return err
 	}
@@ -60,7 +62,7 @@ func (lvm *LVM) gatherPhysicalVolumes(acc telegraf.Accumulator) error {
 	var report pvsReport
 	err = json.Unmarshal(out, &report)
 	if err != nil {
-		return fmt.Errorf("failed to unmarshal physical volume JSON: %s", err)
+		return fmt.Errorf("failed to unmarshal physical volume JSON: %w", err)
 	}
 
 	if len(report.Report) > 0 {
@@ -102,12 +104,11 @@ func (lvm *LVM) gatherPhysicalVolumes(acc telegraf.Accumulator) error {
 }
 
 func (lvm *LVM) gatherVolumeGroups(acc telegraf.Accumulator) error {
-	cmd := "/usr/sbin/vgs"
 	args := []string{
 		"--reportformat", "json", "--units", "b", "--nosuffix",
 		"-o", "vg_name,pv_count,lv_count,snap_count,vg_size,vg_free",
 	}
-	out, err := lvm.runCmd(cmd, args)
+	out, err := lvm.runCmd(lvm.VGSBinary, args)
 	if err != nil {
 		return err
 	}
@@ -115,7 +116,7 @@ func (lvm *LVM) gatherVolumeGroups(acc telegraf.Accumulator) error {
 	var report vgsReport
 	err = json.Unmarshal(out, &report)
 	if err != nil {
-		return fmt.Errorf("failed to unmarshal vol group JSON: %s", err)
+		return fmt.Errorf("failed to unmarshal vol group JSON: %w", err)
 	}
 
 	if len(report.Report) > 0 {
@@ -166,12 +167,11 @@ func (lvm *LVM) gatherVolumeGroups(acc telegraf.Accumulator) error {
 }
 
 func (lvm *LVM) gatherLogicalVolumes(acc telegraf.Accumulator) error {
-	cmd := "/usr/sbin/lvs"
 	args := []string{
 		"--reportformat", "json", "--units", "b", "--nosuffix",
 		"-o", "lv_name,vg_name,lv_size,data_percent,metadata_percent",
 	}
-	out, err := lvm.runCmd(cmd, args)
+	out, err := lvm.runCmd(lvm.LVSBinary, args)
 	if err != nil {
 		return err
 	}
@@ -179,7 +179,7 @@ func (lvm *LVM) gatherLogicalVolumes(acc telegraf.Accumulator) error {
 	var report lvsReport
 	err = json.Unmarshal(out, &report)
 	if err != nil {
-		return fmt.Errorf("failed to unmarshal logical vol JSON: %s", err)
+		return fmt.Errorf("failed to unmarshal logical vol JSON: %w", err)
 	}
 
 	if len(report.Report) > 0 {
@@ -234,8 +234,7 @@ func (lvm *LVM) runCmd(cmd string, args []string) ([]byte, error) {
 	out, err := internal.StdOutputTimeout(execCmd, 5*time.Second)
 	if err != nil {
 		return nil, fmt.Errorf(
-			"failed to run command %s: %s - %s",
-			strings.Join(execCmd.Args, " "), err, string(out),
+			"failed to run command %s: %w - %s", strings.Join(execCmd.Args, " "), err, string(out),
 		)
 	}
 
@@ -284,6 +283,10 @@ type lvsReport struct {
 
 func init() {
 	inputs.Add("lvm", func() telegraf.Input {
-		return &LVM{}
+		return &LVM{
+			PVSBinary: "/usr/sbin/pvs",
+			VGSBinary: "/usr/sbin/vgs",
+			LVSBinary: "/usr/sbin/lvs",
+		}
 	})
 }
