@@ -16,8 +16,6 @@ import (
 	"github.com/influxdata/telegraf/plugins/inputs"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
-//
 //go:embed sample.conf
 var sampleConfig string
 
@@ -135,7 +133,7 @@ func (c *Marklogic) Gather(accumulator telegraf.Accumulator) error {
 		go func(serv string) {
 			defer wg.Done()
 			if err := c.fetchAndInsertData(accumulator, serv); err != nil {
-				accumulator.AddError(fmt.Errorf("[host=%s]: %s", serv, err))
+				accumulator.AddError(fmt.Errorf("[host=%s]: %w", serv, err))
 			}
 		}(serv)
 	}
