@@ -8,10 +8,10 @@ import (
 	"testing"
 	"time"
 
+	"github.com/stretchr/testify/require"
+
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/testutil"
-	"github.com/stretchr/testify/assert"
-	"github.com/stretchr/testify/require"
 )
 
 type transportMock struct {
@@ -579,8 +579,9 @@ func TestConnection(t *testing.T) {
 
 	err := r.Gather(&acc)
 	require.Error(t, err)
-	_, ok := err.(*url.Error)
-	require.True(t, ok)
+
+	var urlErr *url.Error
+	require.ErrorAs(t, err, &urlErr)
 }
 
 func TestInvalidUsernameOrPassword(t *testing.T) {
@@ -632,7 +633,7 @@ func TestNoUsernameOrPasswordConfiguration(t *testing.T) {
 	require.NoError(t, r.Init())
 
 	err := r.Gather(&acc)
-	assert.EqualError(t, err, "received status code 401 (Unauthorized), expected 200")
+	require.EqualError(t, err, "received status code 401 (Unauthorized), expected 200")
 }
 
 func TestInvalidXMLAndInvalidTypes(t *testing.T) {
