@@ -45,8 +45,6 @@ import (
 	"github.com/influxdata/telegraf/plugins/inputs"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
-//
 //go:embed sample.conf
 var sampleConfig string
 
@@ -147,7 +145,7 @@ func (o *OpenStack) Init() error {
 	}
 	provider, err := openstack.NewClient(authOption.IdentityEndpoint)
 	if err != nil {
-		return fmt.Errorf("unable to create client for OpenStack endpoint %v", err)
+		return fmt.Errorf("unable to create client for OpenStack endpoint: %w", err)
 	}
 
 	ctx := context.Background()
@@ -159,38 +157,38 @@ func (o *OpenStack) Init() error {
 	provider.HTTPClient = *client
 
 	if err := openstack.Authenticate(provider, authOption); err != nil {
-		return fmt.Errorf("unable to authenticate OpenStack user %v", err)
+		return fmt.Errorf("unable to authenticate OpenStack user: %w", err)
 	}
 
 	// Create required clients and attach to the OpenStack struct
 	if o.identity, err = openstack.NewIdentityV3(provider, gophercloud.EndpointOpts{}); err != nil {
-		return fmt.Errorf("unable to create V3 identity client %v", err)
+		return fmt.Errorf("unable to create V3 identity client: %w", err)
 	}
 
 	if err := o.gatherServices(); err != nil {
-		return fmt.Errorf("failed to get resource openstack services %v", err)
+		return fmt.Errorf("failed to get resource openstack services: %w", err)
 	}
 
 	if o.compute, err = openstack.NewComputeV2(provider, gophercloud.EndpointOpts{}); err != nil {
-		return fmt.Errorf("unable to create V2 compute client %v", err)
+		return fmt.Errorf("unable to create V2 compute client: %w", err)
 	}
 
 	// Create required clients and attach to the OpenStack struct
 	if o.network, err = openstack.NewNetworkV2(provider, gophercloud.EndpointOpts{}); err != nil {
-		return fmt.Errorf("unable to create V2 network client %v", err)
+		return fmt.Errorf("unable to create V2 network client: %w", err)
 	}
 
 	// The Orchestration service is optional
 	if o.containsService("orchestration") {
 		if o.stack, err = openstack.NewOrchestrationV1(provider, gophercloud.EndpointOpts{}); err != nil {
-			return fmt.Errorf("unable to create V1 stack client %v", err)
+			return fmt.Errorf("unable to create V1 stack client: %w", err)
 		}
 	}
 
 	// The Cinder volume storage service is optional
 	if o.containsService("volumev3") {
 		if o.volume, err = openstack.NewBlockStorageV3(provider, gophercloud.EndpointOpts{}); err != nil {
-			return fmt.Errorf("unable to create V3 volume client %v", err)
+			return fmt.Errorf("unable to create V3 volume client: %w", err)
 		}
 	}
 
@@ -228,7 +226,7 @@ func (o *OpenStack) Gather(acc telegraf.Accumulator) error {
 		start := time.Now()
 		gatherer := gatherers[service]
 		if err := gatherer(acc); err != nil {
-			acc.AddError(fmt.Errorf("failed to get resource %q %v", service, err))
+			acc.AddError(fmt.Errorf("failed to get resource %q: %w", service, err))
 		}
 		callDuration[service] = time.Since(start).Nanoseconds()
 	}
@@ -242,7 +240,7 @@ func (o *OpenStack) Gather(acc telegraf.Accumulator) error {
 	if o.ServerDiagnotics {
 		if !choice.Contains("servers", o.EnabledServices) {
 			if err := o.gatherServers(acc); err != nil {
-				acc.AddError(fmt.Errorf("failed to get resource server diagnostics %v", err))
+				acc.AddError(fmt.Errorf("failed to get resource server diagnostics: %w", err))
 				return nil
 			}
 		}
@@ -256,11 +254,11 @@ func (o *OpenStack) Gather(acc telegraf.Accumulator) error {
 func (o *OpenStack) gatherServices() error {
 	page, err := services.List(o.identity, &services.ListOpts{}).AllPages()
 	if err != nil {
-		return fmt.Errorf("unable to list services %v", err)
+		return fmt.Errorf("unable to list services: %w", err)
 	}
 	extractedServices, err := services.ExtractServices(page)
 	if err != nil {
-		return fmt.Errorf("unable to extract services %v", err)
+		return fmt.Errorf("unable to extract services: %w", err)
 	}
 	for _, service := range extractedServices {
 		o.openstackServices[service.ID] = service
@@ -273,11 +271,11 @@ func (o *OpenStack) gatherServices() error {
 func (o *OpenStack) gatherStacks(acc telegraf.Accumulator) error {
 	page, err := stacks.List(o.stack, &stacks.ListOpts{}).AllPages()
 	if err != nil {
-		return fmt.Errorf("unable to list stacks %v", err)
+		return fmt.Errorf("unable to list stacks: %w", err)
 	}
 	extractedStacks, err := stacks.ExtractStacks(page)
 	if err != nil {
-		return fmt.Errorf("unable to extract stacks %v", err)
+		return fmt.Errorf("unable to extract stacks: %w", err)
 	}
 	for _, stack := range extractedStacks {
 		tags := map[string]string{
@@ -304,11 +302,11 @@ func (o *OpenStack) gatherStacks(acc telegraf.Accumulator) error {
 func (o *OpenStack) gatherNovaServices(acc telegraf.Accumulator) error {
 	page, err := nova_services.List(o.compute, &nova_services.ListOpts{}).AllPages()
 	if err != nil {
-		return fmt.Errorf("unable to list nova_services %v", err)
+		return fmt.Errorf("unable to list nova_services: %w", err)
 	}
 	novaServices, err := nova_services.ExtractServices(page)
 	if err != nil {
-		return fmt.Errorf("unable to extract nova_services %v", err)
+		return fmt.Errorf("unable to extract nova_services: %w", err)
 	}
 	for _, novaService := range novaServices {
 		tags := map[string]string{
@@ -334,11 +332,11 @@ func (o *OpenStack) gatherNovaServices(acc telegraf.Accumulator) error {
 func (o *OpenStack) gatherSubnets(acc telegraf.Accumulator) error {
 	page, err := subnets.List(o.network, &subnets.ListOpts{}).AllPages()
 	if err != nil {
-		return fmt.Errorf("unable to list subnets %v", err)
+		return fmt.Errorf("unable to list subnets: %w", err)
 	}
 	extractedSubnets, err := subnets.ExtractSubnets(page)
 	if err != nil {
-		return fmt.Errorf("unable to extract subnets %v", err)
+		return fmt.Errorf("unable to extract subnets: %w", err)
 	}
 	for _, subnet := range extractedSubnets {
 		var allocationPools []string
@@ -376,11 +374,11 @@ func (o *OpenStack) gatherSubnets(acc telegraf.Accumulator) error {
 func (o *OpenStack) gatherPorts(acc telegraf.Accumulator) error {
 	page, err := ports.List(o.network, &ports.ListOpts{}).AllPages()
 	if err != nil {
-		return fmt.Errorf("unable to list ports %v", err)
+		return fmt.Errorf("unable to list ports: %w", err)
 	}
 	extractedPorts, err := ports.ExtractPorts(page)
 	if err != nil {
-		return fmt.Errorf("unable to extract ports %v", err)
+		return fmt.Errorf("unable to extract ports: %w", err)
 	}
 	for _, port := range extractedPorts {
 		tags := map[string]string{
@@ -421,11 +419,11 @@ func (o *OpenStack) gatherPorts(acc telegraf.Accumulator) error {
 func (o *OpenStack) gatherNetworks(acc telegraf.Accumulator) error {
 	page, err := networks.List(o.network, &networks.ListOpts{}).AllPages()
 	if err != nil {
-		return fmt.Errorf("unable to list networks %v", err)
+		return fmt.Errorf("unable to list networks: %w", err)
 	}
 	extractedNetworks, err := networks.ExtractNetworks(page)
 	if err != nil {
-		return fmt.Errorf("unable to extract networks %v", err)
+		return fmt.Errorf("unable to extract networks: %w", err)
 	}
 	for _, network := range extractedNetworks {
 		tags := map[string]string{
@@ -463,11 +461,11 @@ func (o *OpenStack) gatherNetworks(acc telegraf.Accumulator) error {
 func (o *OpenStack) gatherAgents(acc telegraf.Accumulator) error {
 	page, err := agents.List(o.network, &agents.ListOpts{}).AllPages()
 	if err != nil {
-		return fmt.Errorf("unable to list neutron agents %v", err)
+		return fmt.Errorf("unable to list neutron agents: %w", err)
 	}
 	extractedAgents, err := agents.ExtractAgents(page)
 	if err != nil {
-		return fmt.Errorf("unable to extract neutron agents %v", err)
+		return fmt.Errorf("unable to extract neutron agents: %w", err)
 	}
 	for _, agent := range extractedAgents {
 		tags := map[string]string{
@@ -496,11 +494,11 @@ func (o *OpenStack) gatherAgents(acc telegraf.Accumulator) error {
 func (o *OpenStack) gatherAggregates(acc telegraf.Accumulator) error {
 	page, err := aggregates.List(o.compute).AllPages()
 	if err != nil {
-		return fmt.Errorf("unable to list aggregates %v", err)
+		return fmt.Errorf("unable to list aggregates: %w", err)
 	}
 	extractedAggregates, err := aggregates.ExtractAggregates(page)
 	if err != nil {
-		return fmt.Errorf("unable to extract aggregates %v", err)
+		return fmt.Errorf("unable to extract aggregates: %w", err)
 	}
 	for _, aggregate := range extractedAggregates {
 		tags := map[string]string{
@@ -531,11 +529,11 @@ func (o *OpenStack) gatherAggregates(acc telegraf.Accumulator) error {
 func (o *OpenStack) gatherProjects(acc telegraf.Accumulator) error {
 	page, err := projects.List(o.identity, &projects.ListOpts{}).AllPages()
 	if err != nil {
-		return fmt.Errorf("unable to list projects %v", err)
+		return fmt.Errorf("unable to list projects: %w", err)
 	}
 	extractedProjects, err := projects.ExtractProjects(page)
 	if err != nil {
-		return fmt.Errorf("unable to extract projects %v", err)
+		return fmt.Errorf("unable to extract projects: %w", err)
 	}
 	for _, project := range extractedProjects {
 		o.openstackProjects[project.ID] = project
@@ -563,11 +561,11 @@ func (o *OpenStack) gatherProjects(acc telegraf.Accumulator) error {
 func (o *OpenStack) gatherHypervisors(acc telegraf.Accumulator) error {
 	page, err := hypervisors.List(o.compute, hypervisors.ListOpts{}).AllPages()
 	if err != nil {
-		return fmt.Errorf("unable to list hypervisors %v", err)
+		return fmt.Errorf("unable to list hypervisors: %w", err)
 	}
 	extractedHypervisors, err := hypervisors.ExtractHypervisors(page)
 	if err != nil {
-		return fmt.Errorf("unable to extract hypervisors %v", err)
+		return fmt.Errorf("unable to extract hypervisors: %w", err)
 	}
 	o.openstackHypervisors = extractedHypervisors
 	if choice.Contains("hypervisors", o.EnabledServices) {
@@ -616,11 +614,11 @@ func (o *OpenStack) gatherHypervisors(acc telegraf.Accumulator) error {
 func (o *OpenStack) gatherFlavors(acc telegraf.Accumulator) error {
 	page, err := flavors.ListDetail(o.compute, &flavors.ListOpts{}).AllPages()
 	if err != nil {
-		return fmt.Errorf("unable to list flavors %v", err)
+		return fmt.Errorf("unable to list flavors: %w", err)
 	}
 	extractedflavors, err := flavors.ExtractFlavors(page)
 	if err != nil {
-		return fmt.Errorf("unable to extract flavors %v", err)
+		return fmt.Errorf("unable to extract flavors: %w", err)
 	}
 	for _, flavor := range extractedflavors {
 		o.openstackFlavors[flavor.ID] = flavor
@@ -646,11 +644,11 @@ func (o *OpenStack) gatherFlavors(acc telegraf.Accumulator) error {
 func (o *OpenStack) gatherVolumes(acc telegraf.Accumulator) error {
 	page, err := volumes.List(o.volume, &volumes.ListOpts{AllTenants: true}).AllPages()
 	if err != nil {
-		return fmt.Errorf("unable to list volumes %v", err)
+		return fmt.Errorf("unable to list volumes: %w", err)
 	}
 	v := []volume{}
 	if err := volumes.ExtractVolumesInto(page, &v); err != nil {
-		return fmt.Errorf("unable to extract volumes %v", err)
+		return fmt.Errorf("unable to extract volumes: %w", err)
 	}
 	for _, volume := range v {
 		tags := map[string]string{
@@ -701,11 +699,11 @@ func (o *OpenStack) gatherVolumes(acc telegraf.Accumulator) error {
 func (o *OpenStack) gatherStoragePools(acc telegraf.Accumulator) error {
 	results, err := schedulerstats.List(o.volume, &schedulerstats.ListOpts{Detail: true}).AllPages()
 	if err != nil {
-		return fmt.Errorf("unable to list storage pools %v", err)
+		return fmt.Errorf("unable to list storage pools: %w", err)
 	}
 	storagePools, err := schedulerstats.ExtractStoragePools(results)
 	if err != nil {
-		return fmt.Errorf("unable to extract storage pools %v", err)
+		return fmt.Errorf("unable to extract storage pools: %w", err)
 	}
 	for _, storagePool := range storagePools {
 		tags := map[string]string{
@@ -728,18 +726,18 @@ func (o *OpenStack) gatherStoragePools(acc telegraf.Accumulator) error {
 func (o *OpenStack) gatherServers(acc telegraf.Accumulator) error {
 	if !choice.Contains("hypervisors", o.EnabledServices) {
 		if err := o.gatherHypervisors(acc); err != nil {
-			acc.AddError(fmt.Errorf("failed to get resource hypervisors %v", err))
+			acc.AddError(fmt.Errorf("failed to get resource hypervisors: %w", err))
 		}
 	}
 	serverGather := choice.Contains("servers", o.EnabledServices)
 	for _, hypervisor := range o.openstackHypervisors {
 		page, err := servers.List(o.compute, &servers.ListOpts{AllTenants: true, Host: hypervisor.HypervisorHostname}).AllPages()
 		if err != nil {
-			return fmt.Errorf("unable to list servers %v", err)
+			return fmt.Errorf("unable to list servers: %w", err)
 		}
 		extractedServers, err := servers.ExtractServers(page)
 		if err != nil {
-			return fmt.Errorf("unable to extract servers %v", err)
+			return fmt.Errorf("unable to extract servers: %w", err)
 		}
 		for _, server := range extractedServers {
 			if serverGather {
@@ -750,7 +748,7 @@ func (o *OpenStack) gatherServers(acc telegraf.Accumulator) error {
 			}
 			diagnostic, err := diagnostics.Get(o.compute, server.ID).Extract()
 			if err != nil {
-				acc.AddError(fmt.Errorf("unable to get diagnostics for server(%v) %v", server.ID, err))
+				acc.AddError(fmt.Errorf("unable to get diagnostics for server %q: %w", server.ID, err))
 				continue
 			}
 			o.diag[server.ID] = diagnostic
