@@ -14,7 +14,7 @@ import (
 	"sync"
 	"time"
 
-	"github.com/go-ping/ping"
+	ping "github.com/prometheus-community/pro-bing"
 
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/internal"
@@ -165,7 +165,7 @@ func (p *Ping) nativePing(destination string) (*pingStats, error) {
 	once := &sync.Once{}
 	pinger.OnRecv = func(pkt *ping.Packet) {
 		once.Do(func() {
-			ps.ttl = pkt.Ttl
+			ps.ttl = pkt.TTL
 		})
 	}
 
@@ -179,7 +179,7 @@ func (p *Ping) nativePing(destination string) (*pingStats, error) {
 
 			return nil, fmt.Errorf("permission changes required, refer to the ping plugin's README.md for more info")
 		}
-		return nil, fmt.Errorf("%w", err)
+		return nil, err
 	}
 
 	ps.Statistics = *pinger.Statistics()
