@@ -1,22 +1,20 @@
-// +build !windows
+//go:build !windows
 
 package ping
 
 import (
-	"context"
 	"errors"
 	"fmt"
-	"net"
 	"reflect"
 	"sort"
 	"testing"
 	"time"
 
-	"github.com/go-ping/ping"
+	ping "github.com/prometheus-community/pro-bing"
+	"github.com/stretchr/testify/require"
+
 	"github.com/influxdata/telegraf/plugins/inputs"
 	"github.com/influxdata/telegraf/testutil"
-	"github.com/stretchr/testify/assert"
-	"github.com/stretchr/testify/require"
 )
 
 // BSD/Darwin ping output
@@ -81,45 +79,45 @@ ping: -i interval too short: Operation not permitted
 
 // Test that ping command output is processed properly
 func TestProcessPingOutput(t *testing.T) {
-	trans, rec, ttl, min, avg, max, stddev, err := processPingOutput(bsdPingOutput)
-	assert.NoError(t, err)
-	assert.Equal(t, 55, ttl, "ttl value is 55")
-	assert.Equal(t, 5, trans, "5 packets were transmitted")
-	assert.Equal(t, 5, rec, "5 packets were received")
-	assert.InDelta(t, 15.087, min, 0.001)
-	assert.InDelta(t, 20.224, avg, 0.001)
-	assert.InDelta(t, 27.263, max, 0.001)
-	assert.InDelta(t, 4.076, stddev, 0.001)
+	stats, err := processPingOutput(bsdPingOutput)
+	require.NoError(t, err)
+	require.Equal(t, 55, stats.ttl, "ttl value is 55")
+	require.Equal(t, 5, stats.trans, "5 packets were transmitted")
+	require.Equal(t, 5, stats.recv, "5 packets were received")
+	require.InDelta(t, 15.087, stats.min, 0.001)
+	require.InDelta(t, 20.224, stats.avg, 0.001)
+	require.InDelta(t, 27.263, stats.max, 0.001)
+	require.InDelta(t, 4.076, stats.stddev, 0.001)
 
-	trans, rec, ttl, min, avg, max, stddev, err = processPingOutput(freebsdPing6Output)
-	assert.NoError(t, err)
-	assert.Equal(t, 117, ttl, "ttl value is 117")
-	assert.Equal(t, 5, trans, "5 packets were transmitted")
-	assert.Equal(t, 5, rec, "5 packets were received")
-	assert.InDelta(t, 35.727, min, 0.001)
-	assert.InDelta(t, 53.211, avg, 0.001)
-	assert.InDelta(t, 93.870, max, 0.001)
-	assert.InDelta(t, 22.000, stddev, 0.001)
+	stats, err = processPingOutput(freebsdPing6Output)
+	require.NoError(t, err)
+	require.Equal(t, 117, stats.ttl, "ttl value is 117")
+	require.Equal(t, 5, stats.trans, "5 packets were transmitted")
+	require.Equal(t, 5, stats.recv, "5 packets were received")
+	require.InDelta(t, 35.727, stats.min, 0.001)
+	require.InDelta(t, 53.211, stats.avg, 0.001)
+	require.InDelta(t, 93.870, stats.max, 0.001)
+	require.InDelta(t, 22.000, stats.stddev, 0.001)
 
-	trans, rec, ttl, min, avg, max, stddev, err = processPingOutput(linuxPingOutput)
-	assert.NoError(t, err)
-	assert.Equal(t, 63, ttl, "ttl value is 63")
-	assert.Equal(t, 5, trans, "5 packets were transmitted")
-	assert.Equal(t, 5, rec, "5 packets were received")
-	assert.InDelta(t, 35.225, min, 0.001)
-	assert.InDelta(t, 43.628, avg, 0.001)
-	assert.InDelta(t, 51.806, max, 0.001)
-	assert.InDelta(t, 5.325, stddev, 0.001)
+	stats, err = processPingOutput(linuxPingOutput)
+	require.NoError(t, err)
+	require.Equal(t, 63, stats.ttl, "ttl value is 63")
+	require.Equal(t, 5, stats.trans, "5 packets were transmitted")
+	require.Equal(t, 5, stats.recv, "5 packets were received")
+	require.InDelta(t, 35.225, stats.min, 0.001)
+	require.InDelta(t, 43.628, stats.avg, 0.001)
+	require.InDelta(t, 51.806, stats.max, 0.001)
+	require.InDelta(t, 5.325, stats.stddev, 0.001)
 
-	trans, rec, ttl, min, avg, max, stddev, err = processPingOutput(busyBoxPingOutput)
-	assert.NoError(t, err)
-	assert.Equal(t, 56, ttl, "ttl value is 56")
-	assert.Equal(t, 4, trans, "4 packets were transmitted")
-	assert.Equal(t, 4, rec, "4 packets were received")
-	assert.InDelta(t, 15.810, min, 0.001)
-	assert.InDelta(t, 17.611, avg, 0.001)
-	assert.InDelta(t, 22.559, max, 0.001)
-	assert.InDelta(t, -1.0, stddev, 0.001)
+	stats, err = processPingOutput(busyBoxPingOutput)
+	require.NoError(t, err)
+	require.Equal(t, 56, stats.ttl, "ttl value is 56")
+	require.Equal(t, 4, stats.trans, "4 packets were transmitted")
+	require.Equal(t, 4, stats.recv, "4 packets were received")
+	require.InDelta(t, 15.810, stats.min, 0.001)
+	require.InDelta(t, 17.611, stats.avg, 0.001)
+	require.InDelta(t, 22.559, stats.max, 0.001)
+	require.InDelta(t, -1.0, stats.stddev, 0.001)
 }
 
 // Linux ping output with varying TTL
@@ -138,22 +136,22 @@ rtt min/avg/max/mdev = 35.225/43.628/51.806/5.325 ms
 
 // Test that ping command output is processed properly
 func TestProcessPingOutputWithVaryingTTL(t *testing.T) {
-	trans, rec, ttl, min, avg, max, stddev, err := processPingOutput(linuxPingOutputWithVaryingTTL)
-	assert.NoError(t, err)
-	assert.Equal(t, 63, ttl, "ttl value is 63")
-	assert.Equal(t, 5, trans, "5 packets were transmitted")
-	assert.Equal(t, 5, rec, "5 packets were transmitted")
-	assert.InDelta(t, 35.225, min, 0.001)
-	assert.InDelta(t, 43.628, avg, 0.001)
-	assert.InDelta(t, 51.806, max, 0.001)
-	assert.InDelta(t, 5.325, stddev, 0.001)
+	stats, err := processPingOutput(linuxPingOutputWithVaryingTTL)
+	require.NoError(t, err)
+	require.Equal(t, 63, stats.ttl, "ttl value is 63")
+	require.Equal(t, 5, stats.trans, "5 packets were transmitted")
+	require.Equal(t, 5, stats.recv, "5 packets were transmitted")
+	require.InDelta(t, 35.225, stats.min, 0.001)
+	require.InDelta(t, 43.628, stats.avg, 0.001)
+	require.InDelta(t, 51.806, stats.max, 0.001)
+	require.InDelta(t, 5.325, stats.stddev, 0.001)
 }
 
 // Test that processPingOutput returns an error when 'ping' fails to run, such
 // as when an invalid argument is provided
 func TestErrorProcessPingOutput(t *testing.T) {
-	_, _, _, _, _, _, _, err := processPingOutput(fatalPingOutput)
-	assert.Error(t, err, "Error was expected from processPingOutput")
+	_, err := processPingOutput(fatalPingOutput)
+	require.Error(t, err, "Error was expected from processPingOutput")
 }
 
 // Test that default arg lists are created correctly
@@ -231,7 +229,7 @@ func TestArguments(t *testing.T) {
 	}
 }
 
-func mockHostPinger(binary string, timeout float64, args ...string) (string, error) {
+func mockHostPinger(_ string, _ float64, _ ...string) (string, error) {
 	return linuxPingOutput, nil
 }
 
@@ -243,7 +241,7 @@ func TestPingGather(t *testing.T) {
 		pingHost: mockHostPinger,
 	}
 
-	acc.GatherError(p.Gather)
+	require.NoError(t, acc.GatherError(p.Gather))
 	tags := map[string]string{"url": "localhost"}
 	fields := map[string]interface{}{
 		"packets_transmitted":   5,
@@ -272,8 +270,8 @@ func TestPingGatherIntegration(t *testing.T) {
 	p.Log = testutil.Logger{}
 	require.True(t, ok)
 	p.Urls = []string{"localhost", "influxdata.com"}
-	err := acc.GatherError(p.Gather)
-	require.NoError(t, err)
+	require.NoError(t, acc.GatherError(p.Gather))
+
 	require.Equal(t, 0, acc.Metrics[0].Fields["result_code"])
 	require.Equal(t, 0, acc.Metrics[1].Fields["result_code"])
 }
@@ -289,7 +287,7 @@ PING www.google.com (216.58.218.164) 56(84) bytes of data.
 rtt min/avg/max/mdev = 35.225/44.033/51.806/5.325 ms
 `
 
-func mockLossyHostPinger(binary string, timeout float64, args ...string) (string, error) {
+func mockLossyHostPinger(_ string, _ float64, _ ...string) (string, error) {
 	return lossyPingOutput, nil
 }
 
@@ -301,7 +299,7 @@ func TestLossyPingGather(t *testing.T) {
 		pingHost: mockLossyHostPinger,
 	}
 
-	acc.GatherError(p.Gather)
+	require.NoError(t, acc.GatherError(p.Gather))
 	tags := map[string]string{"url": "www.google.com"}
 	fields := map[string]interface{}{
 		"packets_transmitted":   5,
@@ -325,7 +323,7 @@ Request timeout for icmp_seq 0
 2 packets transmitted, 0 packets received, 100.0% packet loss
 `
 
-func mockErrorHostPinger(binary string, timeout float64, args ...string) (string, error) {
+func mockErrorHostPinger(_ string, _ float64, _ ...string) (string, error) {
 	// This error will not trigger correct error paths
 	return errorPingOutput, nil
 }
@@ -339,7 +337,7 @@ func TestBadPingGather(t *testing.T) {
 		pingHost: mockErrorHostPinger,
 	}
 
-	acc.GatherError(p.Gather)
+	require.NoError(t, acc.GatherError(p.Gather))
 	tags := map[string]string{"url": "www.amazon.com"}
 	fields := map[string]interface{}{
 		"packets_transmitted": 2,
@@ -350,8 +348,8 @@ func TestBadPingGather(t *testing.T) {
 	acc.AssertContainsTaggedFields(t, "ping", fields, tags)
 }
 
-func mockFatalHostPinger(binary string, timeout float64, args ...string) (string, error) {
-	return fatalPingOutput, errors.New("So very bad")
+func mockFatalHostPinger(_ string, _ float64, _ ...string) (string, error) {
+	return fatalPingOutput, errors.New("so very bad")
 }
 
 // Test that a fatal ping command does not gather any statistics.
@@ -362,20 +360,22 @@ func TestFatalPingGather(t *testing.T) {
 		pingHost: mockFatalHostPinger,
 	}
 
-	acc.GatherError(p.Gather)
-	assert.False(t, acc.HasMeasurement("packets_transmitted"),
+	err := acc.GatherError(p.Gather)
+	require.Error(t, err)
+	require.EqualValues(t, "host \"www.amazon.com\": so very bad - ping: -i interval too short: Operation not permitted", err.Error())
+	require.False(t, acc.HasMeasurement("packets_transmitted"),
 		"Fatal ping should not have packet measurements")
-	assert.False(t, acc.HasMeasurement("packets_received"),
+	require.False(t, acc.HasMeasurement("packets_received"),
 		"Fatal ping should not have packet measurements")
-	assert.False(t, acc.HasMeasurement("percent_packet_loss"),
+	require.False(t, acc.HasMeasurement("percent_packet_loss"),
 		"Fatal ping should not have packet measurements")
-	assert.False(t, acc.HasMeasurement("ttl"),
+	require.False(t, acc.HasMeasurement("ttl"),
 		"Fatal ping should not have packet measurements")
-	assert.False(t, acc.HasMeasurement("minimum_response_ms"),
+	require.False(t, acc.HasMeasurement("minimum_response_ms"),
 		"Fatal ping should not have packet measurements")
-	assert.False(t, acc.HasMeasurement("average_response_ms"),
+	require.False(t, acc.HasMeasurement("average_response_ms"),
 		"Fatal ping should not have packet measurements")
-	assert.False(t, acc.HasMeasurement("maximum_response_ms"),
+	require.False(t, acc.HasMeasurement("maximum_response_ms"),
 		"Fatal ping should not have packet measurements")
 }
 
@@ -384,8 +384,8 @@ func TestErrorWithHostNamePingGather(t *testing.T) {
 		out   string
 		error error
 	}{
-		{"", errors.New("host www.amazon.com: So very bad")},
-		{"so bad", errors.New("host www.amazon.com: so bad, So very bad")},
+		{"", errors.New("host \"www.amazon.com\": so very bad")},
+		{"so bad", errors.New("host \"www.amazon.com\": so very bad")},
 	}
 
 	for _, param := range params {
@@ -393,12 +393,12 @@ func TestErrorWithHostNamePingGather(t *testing.T) {
 		p := Ping{
 			Urls: []string{"www.amazon.com"},
 			pingHost: func(binary string, timeout float64, args ...string) (string, error) {
-				return param.out, errors.New("So very bad")
+				return param.out, errors.New("so very bad")
 			},
 		}
-		acc.GatherError(p.Gather)
-		assert.True(t, len(acc.Errors) > 0)
-		assert.Contains(t, acc.Errors, param.error)
+		require.Error(t, acc.GatherError(p.Gather))
+		require.Equal(t, 1, len(acc.Errors))
+		require.Contains(t, acc.Errors[0].Error(), param.error.Error())
 	}
 }
 
@@ -408,17 +408,13 @@ func TestPingBinary(t *testing.T) {
 		Urls:   []string{"www.google.com"},
 		Binary: "ping6",
 		pingHost: func(binary string, timeout float64, args ...string) (string, error) {
-			assert.True(t, binary == "ping6")
+			require.True(t, binary == "ping6")
 			return "", nil
 		},
 	}
-	acc.GatherError(p.Gather)
-}
-
-func mockHostResolver(ctx context.Context, ipv6 bool, host string) (*net.IPAddr, error) {
-	ipaddr := net.IPAddr{}
-	ipaddr.IP = net.IPv4(127, 0, 0, 1)
-	return &ipaddr, nil
+	err := acc.GatherError(p.Gather)
+	require.Error(t, err)
+	require.EqualValues(t, "\"www.google.com\": fatal error processing ping output", err.Error())
 }
 
 // Test that Gather function works using native ping
@@ -470,24 +466,22 @@ func TestPingGatherNative(t *testing.T) {
 
 	for _, tc := range tests {
 		var acc testutil.Accumulator
-		err := tc.P.Init()
-		require.NoError(t, err)
+		require.NoError(t, tc.P.Init())
 		require.NoError(t, acc.GatherError(tc.P.Gather))
-		assert.True(t, acc.HasPoint("ping", map[string]string{"url": "localhost"}, "packets_transmitted", 5))
-		assert.True(t, acc.HasPoint("ping", map[string]string{"url": "localhost"}, "packets_received", 5))
-		assert.True(t, acc.HasField("ping", "percentile50_ms"))
-		assert.Equal(t, float64(3), acc.Metrics[0].Fields["percentile50_ms"])
-		assert.True(t, acc.HasField("ping", "percentile95_ms"))
-		assert.Equal(t, float64(4.799999), acc.Metrics[0].Fields["percentile95_ms"])
-		assert.True(t, acc.HasField("ping", "percentile99_ms"))
-		assert.Equal(t, float64(4.96), acc.Metrics[0].Fields["percentile99_ms"])
-		assert.True(t, acc.HasField("ping", "percent_packet_loss"))
-		assert.True(t, acc.HasField("ping", "minimum_response_ms"))
-		assert.True(t, acc.HasField("ping", "average_response_ms"))
-		assert.True(t, acc.HasField("ping", "maximum_response_ms"))
-		assert.True(t, acc.HasField("ping", "standard_deviation_ms"))
+		require.True(t, acc.HasPoint("ping", map[string]string{"url": "localhost"}, "packets_transmitted", 5))
+		require.True(t, acc.HasPoint("ping", map[string]string{"url": "localhost"}, "packets_received", 5))
+		require.True(t, acc.HasField("ping", "percentile50_ms"))
+		require.Equal(t, float64(3), acc.Metrics[0].Fields["percentile50_ms"])
+		require.True(t, acc.HasField("ping", "percentile95_ms"))
+		require.Equal(t, float64(4.799999), acc.Metrics[0].Fields["percentile95_ms"])
+		require.True(t, acc.HasField("ping", "percentile99_ms"))
+		require.Equal(t, float64(4.96), acc.Metrics[0].Fields["percentile99_ms"])
+		require.True(t, acc.HasField("ping", "percent_packet_loss"))
+		require.True(t, acc.HasField("ping", "minimum_response_ms"))
+		require.True(t, acc.HasField("ping", "average_response_ms"))
+		require.True(t, acc.HasField("ping", "maximum_response_ms"))
+		require.True(t, acc.HasField("ping", "standard_deviation_ms"))
 	}
-
 }
 
 func TestNoPacketsSent(t *testing.T) {
@@ -510,8 +504,8 @@ func TestNoPacketsSent(t *testing.T) {
 	}
 
 	var testAcc testutil.Accumulator
-	err := p.Init()
-	require.NoError(t, err)
+	require.NoError(t, p.Init())
+
 	p.pingToURLNative("localhost", &testAcc)
 	require.Zero(t, testAcc.Errors)
 	require.True(t, testAcc.HasField("ping", "result_code"))
@@ -532,8 +526,8 @@ func TestDNSLookupError(t *testing.T) {
 	}
 
 	var testAcc testutil.Accumulator
-	err := p.Init()
-	require.NoError(t, err)
+	require.NoError(t, p.Init())
+
 	p.pingToURLNative("localhost", &testAcc)
 	require.Zero(t, testAcc.Errors)
 	require.True(t, testAcc.HasField("ping", "result_code"))
