@@ -12,6 +12,7 @@ import (
 	"github.com/stretchr/testify/require"
 
 	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/internal/snmp"
 	"github.com/influxdata/telegraf/testutil"
 )
@@ -50,7 +51,6 @@ func newMsgFlagsV3(secLevel string) gosnmp.SnmpV3MsgFlags {
 	default:
 		msgFlags = gosnmp.NoAuthNoPriv
 	}
-
 	return msgFlags
 }
 
@@ -96,7 +96,7 @@ func newUsmSecurityParametersForV3(authProto string, privProto string, username
 	}
 
 	return &gosnmp.UsmSecurityParameters{
-		AuthoritativeEngineID:    "1",
+		AuthoritativeEngineID:    "deadbeef", // has to be between 5 & 32 chars
 		AuthoritativeEngineBoots: 1,
 		AuthoritativeEngineTime:  1,
 		UserName:                 username,
@@ -136,16 +136,11 @@ func newGoSNMP(version gosnmp.SnmpVersion, port uint16) gosnmp.GoSNMP {
 }
 
 func sendTrap(t *testing.T, goSNMP gosnmp.GoSNMP, trap gosnmp.SnmpTrap) {
-	err := goSNMP.Connect()
-	if err != nil {
-		t.Errorf("Connect() err: %v", err)
-	}
+	require.NoError(t, goSNMP.Connect())
 	defer goSNMP.Conn.Close()
 
-	_, err = goSNMP.SendTrap(trap)
-	if err != nil {
-		t.Errorf("SendTrap() err: %v", err)
-	}
+	_, err := goSNMP.SendTrap(trap)
+	require.NoError(t, err)
 }
 
 func TestReceiveTrap(t *testing.T) {
@@ -1280,22 +1275,22 @@ func TestReceiveTrap(t *testing.T) {
 				//if cold start be answer otherwise err
 				Log:          testutil.Logger{},
 				Version:      tt.version.String(),
-				SecName:      tt.secName,
+				SecName:      config.NewSecret([]byte(tt.secName)),
 				SecLevel:     tt.secLevel,
 				AuthProtocol: tt.authProto,
-				AuthPassword: tt.authPass,
+				AuthPassword: config.NewSecret([]byte(tt.authPass)),
 				PrivProtocol: tt.privProto,
-				PrivPassword: tt.privPass,
+				PrivPassword: config.NewSecret([]byte(tt.privPass)),
 				Translator:   "netsnmp",
 			}
 
 			require.NoError(t, s.Init())
 
 			//inject test translator
-			s.translator = newTestTranslator(tt.entries)
+			s.transl = newTestTranslator(tt.entries)
 
 			var acc testutil.Accumulator
-			require.Nil(t, s.Start(&acc))
+			require.NoError(t, s.Start(&acc))
 			defer s.Stop()
 
 			var goSNMP gosnmp.GoSNMP
