@@ -24,7 +24,7 @@ import (
 //go:embed sample.conf
 var sampleConfig string
 
-const magicIdleCount int = (-int(^uint(0) >> 1))
+const magicIdleCount = -int(^uint(0) >> 1)
 
 type Query struct {
 	Query               string   `toml:"query"`
@@ -53,7 +53,7 @@ type Query struct {
 	fieldFilterString filter.Filter
 }
 
-func (q *Query) parse(ctx context.Context, acc telegraf.Accumulator, rows *dbsql.Rows, t time.Time) (int, error) {
+func (q *Query) parse(acc telegraf.Accumulator, rows *dbsql.Rows, t time.Time) (int, error) {
 	columnNames, err := rows.Columns()
 	if err != nil {
 		return 0, err
@@ -81,8 +81,12 @@ func (q *Query) parse(ctx context.Context, acc telegraf.Accumulator, rows *dbsql
 
 		for i, name := range columnNames {
 			if q.MeasurementColumn != "" && name == q.MeasurementColumn {
-				var ok bool
-				if measurement, ok = columnData[i].(string); !ok {
+				switch raw := columnData[i].(type) {
+				case string:
+					measurement = raw
+				case []byte:
+					measurement = string(raw)
+				default:
 					return 0, fmt.Errorf("measurement column type \"%T\" unsupported", columnData[i])
 				}
 			}
@@ -105,8 +109,8 @@ func (q *Query) parse(ctx context.Context, acc telegraf.Accumulator, rows *dbsql
 					return 0, fmt.Errorf("time column %q of type \"%T\" unsupported", name, columnData[i])
 				}
 				if !skipParsing {
-					if timestamp, err = internal.ParseTimestamp(q.TimeFormat, fieldvalue, ""); err != nil {
-						return 0, fmt.Errorf("parsing time failed: %v", err)
+					if timestamp, err = internal.ParseTimestamp(q.TimeFormat, fieldvalue, nil); err != nil {
+						return 0, fmt.Errorf("parsing time failed: %w", err)
 					}
 				}
 			}
@@ -114,7 +118,7 @@ func (q *Query) parse(ctx context.Context, acc telegraf.Accumulator, rows *dbsql
 			if q.tagFilter.Match(name) {
 				tagvalue, err := internal.ToString(columnData[i])
 				if err != nil {
-					return 0, fmt.Errorf("converting tag column %q failed: %v", name, err)
+					return 0, fmt.Errorf("converting tag column %q failed: %w", name, err)
 				}
 				if v := strings.TrimSpace(tagvalue); v != "" {
 					tags[name] = v
@@ -125,7 +129,7 @@ func (q *Query) parse(ctx context.Context, acc telegraf.Accumulator, rows *dbsql
 			if q.fieldFilterFloat.Match(name) {
 				v, err := internal.ToFloat64(columnData[i])
 				if err != nil {
-					return 0, fmt.Errorf("converting field column %q to float failed: %v", name, err)
+					return 0, fmt.Errorf("converting field column %q to float failed: %w", name, err)
 				}
 				fields[name] = v
 				continue
@@ -134,7 +138,7 @@ func (q *Query) parse(ctx context.Context, acc telegraf.Accumulator, rows *dbsql
 			if q.fieldFilterInt.Match(name) {
 				v, err := internal.ToInt64(columnData[i])
 				if err != nil {
-					return 0, fmt.Errorf("converting field column %q to int failed: %v", name, err)
+					return 0, fmt.Errorf("converting field column %q to int failed: %w", name, err)
 				}
 				fields[name] = v
 				continue
@@ -143,7 +147,7 @@ func (q *Query) parse(ctx context.Context, acc telegraf.Accumulator, rows *dbsql
 			if q.fieldFilterUint.Match(name) {
 				v, err := internal.ToUint64(columnData[i])
 				if err != nil {
-					return 0, fmt.Errorf("converting field column %q to uint failed: %v", name, err)
+					return 0, fmt.Errorf("converting field column %q to uint failed: %w", name, err)
 				}
 				fields[name] = v
 				continue
@@ -152,7 +156,7 @@ func (q *Query) parse(ctx context.Context, acc telegraf.Accumulator, rows *dbsql
 			if q.fieldFilterBool.Match(name) {
 				v, err := internal.ToBool(columnData[i])
 				if err != nil {
-					return 0, fmt.Errorf("converting field column %q to bool failed: %v", name, err)
+					return 0, fmt.Errorf("converting field column %q to bool failed: %w", name, err)
 				}
 				fields[name] = v
 				continue
@@ -161,7 +165,7 @@ func (q *Query) parse(ctx context.Context, acc telegraf.Accumulator, rows *dbsql
 			if q.fieldFilterString.Match(name) {
 				v, err := internal.ToString(columnData[i])
 				if err != nil {
-					return 0, fmt.Errorf("converting field column %q to string failed: %v", name, err)
+					return 0, fmt.Errorf("converting field column %q to string failed: %w", name, err)
 				}
 				fields[name] = v
 				continue
@@ -202,7 +206,7 @@ func (q *Query) parse(ctx context.Context, acc telegraf.Accumulator, rows *dbsql
 
 type SQL struct {
 	Driver             string          `toml:"driver"`
-	Dsn                string          `toml:"dsn"`
+	Dsn                config.Secret   `toml:"dsn"`
 	Timeout            config.Duration `toml:"timeout"`
 	MaxIdleTime        config.Duration `toml:"connection_max_idle_time"`
 	MaxLifetime        config.Duration `toml:"connection_max_life_time"`
@@ -225,8 +229,8 @@ func (s *SQL) Init() error {
 		return errors.New("missing SQL driver option")
 	}
 
-	if s.Dsn == "" {
-		return errors.New("missing data source name (DSN) option")
+	if err := s.checkDSN(); err != nil {
+		return err
 	}
 
 	if s.Timeout <= 0 {
@@ -251,7 +255,7 @@ func (s *SQL) Init() error {
 		if q.Script != "" {
 			query, err := os.ReadFile(q.Script)
 			if err != nil {
-				return fmt.Errorf("reading script %q failed: %v", q.Script, err)
+				return fmt.Errorf("reading script %q failed: %w", q.Script, err)
 			}
 			s.Queries[i].Query = string(query)
 		}
@@ -264,45 +268,45 @@ func (s *SQL) Init() error {
 		// Compile the tag-filter
 		tagfilter, err := filter.NewIncludeExcludeFilterDefaults(q.TagColumnsInclude, q.TagColumnsExclude, false, false)
 		if err != nil {
-			return fmt.Errorf("creating tag filter failed: %v", err)
+			return fmt.Errorf("creating tag filter failed: %w", err)
 		}
 		s.Queries[i].tagFilter = tagfilter
 
 		// Compile the explicit type field-filter
 		fieldfilterFloat, err := filter.NewIncludeExcludeFilterDefaults(q.FieldColumnsFloat, nil, false, false)
 		if err != nil {
-			return fmt.Errorf("creating field filter for float failed: %v", err)
+			return fmt.Errorf("creating field filter for float failed: %w", err)
 		}
 		s.Queries[i].fieldFilterFloat = fieldfilterFloat
 
 		fieldfilterInt, err := filter.NewIncludeExcludeFilterDefaults(q.FieldColumnsInt, nil, false, false)
 		if err != nil {
-			return fmt.Errorf("creating field filter for int failed: %v", err)
+			return fmt.Errorf("creating field filter for int failed: %w", err)
 		}
 		s.Queries[i].fieldFilterInt = fieldfilterInt
 
 		fieldfilterUint, err := filter.NewIncludeExcludeFilterDefaults(q.FieldColumnsUint, nil, false, false)
 		if err != nil {
-			return fmt.Errorf("creating field filter for uint failed: %v", err)
+			return fmt.Errorf("creating field filter for uint failed: %w", err)
 		}
 		s.Queries[i].fieldFilterUint = fieldfilterUint
 
 		fieldfilterBool, err := filter.NewIncludeExcludeFilterDefaults(q.FieldColumnsBool, nil, false, false)
 		if err != nil {
-			return fmt.Errorf("creating field filter for bool failed: %v", err)
+			return fmt.Errorf("creating field filter for bool failed: %w", err)
 		}
 		s.Queries[i].fieldFilterBool = fieldfilterBool
 
 		fieldfilterString, err := filter.NewIncludeExcludeFilterDefaults(q.FieldColumnsString, nil, false, false)
 		if err != nil {
-			return fmt.Errorf("creating field filter for string failed: %v", err)
+			return fmt.Errorf("creating field filter for string failed: %w", err)
 		}
 		s.Queries[i].fieldFilterString = fieldfilterString
 
 		// Compile the field-filter
 		fieldfilter, err := filter.NewIncludeExcludeFilter(q.FieldColumnsInclude, q.FieldColumnsExclude)
 		if err != nil {
-			return fmt.Errorf("creating field filter failed: %v", err)
+			return fmt.Errorf("creating field filter failed: %w", err)
 		}
 		s.Queries[i].fieldFilter = fieldfilter
 
@@ -354,8 +358,14 @@ func (s *SQL) Start(_ telegraf.Accumulator) error {
 	var err error
 
 	// Connect to the database server
-	s.Log.Debugf("Connecting to %q...", s.Dsn)
-	s.db, err = dbsql.Open(s.driverName, s.Dsn)
+	dsnSecret, err := s.Dsn.Get()
+	if err != nil {
+		return fmt.Errorf("getting DSN failed: %w", err)
+	}
+	dsn := string(dsnSecret)
+	config.ReleaseSecret(dsnSecret)
+	s.Log.Debug("Connecting...")
+	s.db, err = dbsql.Open(s.driverName, dsn)
 	if err != nil {
 		return err
 	}
@@ -367,22 +377,22 @@ func (s *SQL) Start(_ telegraf.Accumulator) error {
 	s.db.SetMaxIdleConns(s.MaxIdleConnections)
 
 	// Test if the connection can be established
-	s.Log.Debugf("Testing connectivity...")
+	s.Log.Debug("Testing connectivity...")
 	ctx, cancel := context.WithTimeout(context.Background(), time.Duration(s.Timeout))
 	err = s.db.PingContext(ctx)
 	cancel()
 	if err != nil {
-		return fmt.Errorf("connecting to database failed: %v", err)
+		return fmt.Errorf("connecting to database failed: %w", err)
 	}
 
 	// Prepare the statements
 	for i, q := range s.Queries {
 		s.Log.Debugf("Preparing statement %q...", q.Query)
 		ctx, cancel := context.WithTimeout(context.Background(), time.Duration(s.Timeout))
-		stmt, err := s.db.PrepareContext(ctx, q.Query) //nolint:sqlclosecheck // Closed in Stop()
+		stmt, err := s.db.PrepareContext(ctx, q.Query)
 		cancel()
 		if err != nil {
-			return fmt.Errorf("preparing query %q failed: %v", q.Query, err)
+			return fmt.Errorf("preparing query %q failed: %w", q.Query, err)
 		}
 		s.Queries[i].statement = stmt
 	}
@@ -456,8 +466,15 @@ func (s *SQL) executeQuery(ctx context.Context, acc telegraf.Accumulator, q Quer
 	if err != nil {
 		return err
 	}
-	rowCount, err := q.parse(ctx, acc, rows, tquery)
+	rowCount, err := q.parse(acc, rows, tquery)
 	s.Log.Debugf("Received %d rows and %d columns for query %q", rowCount, len(columnNames), q.Query)
 
 	return err
 }
+
+func (s *SQL) checkDSN() error {
+	if s.Dsn.Empty() {
+		return errors.New("missing data source name (DSN) option")
+	}
+	return nil
+}
