@@ -9,7 +9,6 @@ import (
 	"bytes"
 	"encoding/xml"
 	"fmt"
-	"io"
 	"strings"
 	"unicode/utf16"
 	"unicode/utf8"
@@ -45,7 +44,7 @@ func DecodeUTF16(b []byte) ([]byte, error) {
 // GetFromSnapProcess finds information about process by the given pid
 // Returns process parent pid, threads info handle and process name
 func GetFromSnapProcess(pid uint32) (uint32, uint32, string, error) {
-	snap, err := windows.CreateToolhelp32Snapshot(windows.TH32CS_SNAPPROCESS, uint32(pid))
+	snap, err := windows.CreateToolhelp32Snapshot(windows.TH32CS_SNAPPROCESS, pid)
 	if err != nil {
 		return 0, 0, "", err
 	}
@@ -56,9 +55,9 @@ func GetFromSnapProcess(pid uint32) (uint32, uint32, string, error) {
 		return 0, 0, "", err
 	}
 	for {
-		if pe32.ProcessID == uint32(pid) {
+		if pe32.ProcessID == pid {
 			szexe := windows.UTF16ToString(pe32.ExeFile[:])
-			return uint32(pe32.ParentProcessID), uint32(pe32.Threads), szexe, nil
+			return pe32.ParentProcessID, pe32.Threads, szexe, nil
 		}
 		if err = windows.Process32Next(snap, &pe32); err != nil {
 			break
@@ -97,12 +96,10 @@ func UnrollXMLFields(data []byte, fieldsUsage map[string]int, separator string)
 	for {
 		var node xmlnode
 		err := dec.Decode(&node)
-		if err == io.EOF {
-			break
-		}
 		if err != nil {
 			break
 		}
+
 		var parents []string
 		walkXML([]xmlnode{node}, parents, separator, func(node xmlnode, parents []string, separator string) bool {
 			innerText := strings.TrimSpace(node.Text)
@@ -139,7 +136,7 @@ func walkXML(nodes []xmlnode, parents []string, separator string, f func(xmlnode
 // by adding _<num> if there are several of them
 func UniqueFieldNames(fields []EventField, fieldsUsage map[string]int, separator string) []EventField {
 	var fieldsCounter = map[string]int{}
-	var fieldsUnique []EventField
+	fieldsUnique := make([]EventField, 0, len(fields))
 	for _, field := range fields {
 		fieldName := field.Name
 		if fieldsUsage[field.Name] > 1 {
