@@ -10,24 +10,26 @@ import (
 	"unsafe"
 )
 
-// PerformanceQuery is abstraction for PDH_FMT_COUNTERVALUE_ITEM_DOUBLE
+// CounterValue is abstraction for PdhFmtCountervalueItemDouble
 type CounterValue struct {
 	InstanceName string
 	Value        interface{}
 }
 
 // PerformanceQuery provides wrappers around Windows performance counters API for easy usage in GO
+//
+//nolint:interfacebloat // conditionally allow to contain more methods
 type PerformanceQuery interface {
 	Open() error
 	Close() error
-	AddCounterToQuery(counterPath string) (PDH_HCOUNTER, error)
-	AddEnglishCounterToQuery(counterPath string) (PDH_HCOUNTER, error)
-	GetCounterPath(counterHandle PDH_HCOUNTER) (string, error)
+	AddCounterToQuery(counterPath string) (pdhCounterHandle, error)
+	AddEnglishCounterToQuery(counterPath string) (pdhCounterHandle, error)
+	GetCounterPath(counterHandle pdhCounterHandle) (string, error)
 	ExpandWildCardPath(counterPath string) ([]string, error)
-	GetFormattedCounterValueDouble(hCounter PDH_HCOUNTER) (float64, error)
-	GetRawCounterValue(hCounter PDH_HCOUNTER) (int64, error)
-	GetFormattedCounterArrayDouble(hCounter PDH_HCOUNTER) ([]CounterValue, error)
-	GetRawCounterArray(hCounter PDH_HCOUNTER) ([]CounterValue, error)
+	GetFormattedCounterValueDouble(hCounter pdhCounterHandle) (float64, error)
+	GetRawCounterValue(hCounter pdhCounterHandle) (int64, error)
+	GetFormattedCounterArrayDouble(hCounter pdhCounterHandle) ([]CounterValue, error)
+	GetRawCounterArray(hCounter pdhCounterHandle) ([]CounterValue, error)
 	CollectData() error
 	CollectDataWithTime() (time.Time, error)
 	IsVistaOrNewer() bool
@@ -56,7 +58,7 @@ func NewPdhError(code uint32) error {
 
 // PerformanceQueryImpl is implementation of PerformanceQuery interface, which calls phd.dll functions
 type PerformanceQueryImpl struct {
-	query PDH_HQUERY
+	query pdhQueryHandle
 }
 
 type PerformanceQueryCreatorImpl struct {
@@ -75,9 +77,9 @@ func (m *PerformanceQueryImpl) Open() error {
 			return err
 		}
 	}
-	var handle PDH_HQUERY
+	var handle pdhQueryHandle
 
-	if ret := PdhOpenQuery(0, 0, &handle); ret != ERROR_SUCCESS {
+	if ret := PdhOpenQuery(0, 0, &handle); ret != ErrorSuccess {
 		return NewPdhError(ret)
 	}
 	m.query = handle
@@ -90,46 +92,46 @@ func (m *PerformanceQueryImpl) Close() error {
 		return errors.New("uninitialized query")
 	}
 
-	if ret := PdhCloseQuery(m.query); ret != ERROR_SUCCESS {
+	if ret := PdhCloseQuery(m.query); ret != ErrorSuccess {
 		return NewPdhError(ret)
 	}
 	m.query = 0
 	return nil
 }
 
-func (m *PerformanceQueryImpl) AddCounterToQuery(counterPath string) (PDH_HCOUNTER, error) {
-	var counterHandle PDH_HCOUNTER
+func (m *PerformanceQueryImpl) AddCounterToQuery(counterPath string) (pdhCounterHandle, error) {
+	var counterHandle pdhCounterHandle
 	if m.query == 0 {
 		return 0, errors.New("uninitialized query")
 	}
 
-	if ret := PdhAddCounter(m.query, counterPath, 0, &counterHandle); ret != ERROR_SUCCESS {
+	if ret := PdhAddCounter(m.query, counterPath, 0, &counterHandle); ret != ErrorSuccess {
 		return 0, NewPdhError(ret)
 	}
 	return counterHandle, nil
 }
 
-func (m *PerformanceQueryImpl) AddEnglishCounterToQuery(counterPath string) (PDH_HCOUNTER, error) {
-	var counterHandle PDH_HCOUNTER
+func (m *PerformanceQueryImpl) AddEnglishCounterToQuery(counterPath string) (pdhCounterHandle, error) {
+	var counterHandle pdhCounterHandle
 	if m.query == 0 {
 		return 0, errors.New("uninitialized query")
 	}
-	if ret := PdhAddEnglishCounter(m.query, counterPath, 0, &counterHandle); ret != ERROR_SUCCESS {
+	if ret := PdhAddEnglishCounter(m.query, counterPath, 0, &counterHandle); ret != ErrorSuccess {
 		return 0, NewPdhError(ret)
 	}
 	return counterHandle, nil
 }
 
 // GetCounterPath return counter information for given handle
-func (m *PerformanceQueryImpl) GetCounterPath(counterHandle PDH_HCOUNTER) (string, error) {
+func (m *PerformanceQueryImpl) GetCounterPath(counterHandle pdhCounterHandle) (string, error) {
 	var bufSize uint32
 	var buff []byte
 	var ret uint32
-	if ret = PdhGetCounterInfo(counterHandle, 0, &bufSize, nil); ret == PDH_MORE_DATA {
+	if ret = PdhGetCounterInfo(counterHandle, 0, &bufSize, nil); ret == PdhMoreData {
 		buff = make([]byte, bufSize)
 		bufSize = uint32(len(buff))
-		if ret = PdhGetCounterInfo(counterHandle, 0, &bufSize, &buff[0]); ret == ERROR_SUCCESS {
-			ci := (*PDH_COUNTER_INFO)(unsafe.Pointer(&buff[0])) //nolint:gosec // G103: Valid use of unsafe call to create PDH_COUNTER_INFO
+		if ret = PdhGetCounterInfo(counterHandle, 0, &bufSize, &buff[0]); ret == ErrorSuccess {
+			ci := (*PdhCounterInfo)(unsafe.Pointer(&buff[0])) //nolint:gosec // G103: Valid use of unsafe call to create PDH_COUNTER_INFO
 			return UTF16PtrToString(ci.SzFullPath), nil
 		}
 	}
@@ -142,11 +144,11 @@ func (m *PerformanceQueryImpl) ExpandWildCardPath(counterPath string) ([]string,
 	var buff []uint16
 	var ret uint32
 
-	if ret = PdhExpandWildCardPath(counterPath, nil, &bufSize); ret == PDH_MORE_DATA {
+	if ret = PdhExpandWildCardPath(counterPath, nil, &bufSize); ret == PdhMoreData {
 		buff = make([]uint16, bufSize)
 		bufSize = uint32(len(buff))
 		ret = PdhExpandWildCardPath(counterPath, &buff[0], &bufSize)
-		if ret == ERROR_SUCCESS {
+		if ret == ErrorSuccess {
 			list := UTF16ToStringArray(buff)
 			return list, nil
 		}
@@ -155,36 +157,34 @@ func (m *PerformanceQueryImpl) ExpandWildCardPath(counterPath string) ([]string,
 }
 
 // GetFormattedCounterValueDouble computes a displayable value for the specified counter
-func (m *PerformanceQueryImpl) GetFormattedCounterValueDouble(hCounter PDH_HCOUNTER) (float64, error) {
+func (m *PerformanceQueryImpl) GetFormattedCounterValueDouble(hCounter pdhCounterHandle) (float64, error) {
 	var counterType uint32
-	var value PDH_FMT_COUNTERVALUE_DOUBLE
+	var value PdhFmtCountervalueDouble
 	var ret uint32
 
-	if ret = PdhGetFormattedCounterValueDouble(hCounter, &counterType, &value); ret == ERROR_SUCCESS {
-		if value.CStatus == PDH_CSTATUS_VALID_DATA || value.CStatus == PDH_CSTATUS_NEW_DATA {
+	if ret = PdhGetFormattedCounterValueDouble(hCounter, &counterType, &value); ret == ErrorSuccess {
+		if value.CStatus == PdhCstatusValidData || value.CStatus == PdhCstatusNewData {
 			return value.DoubleValue, nil
-		} else {
-			return 0, NewPdhError(value.CStatus)
 		}
-	} else {
-		return 0, NewPdhError(ret)
+		return 0, NewPdhError(value.CStatus)
 	}
+	return 0, NewPdhError(ret)
 }
 
-func (m *PerformanceQueryImpl) GetFormattedCounterArrayDouble(hCounter PDH_HCOUNTER) ([]CounterValue, error) {
+func (m *PerformanceQueryImpl) GetFormattedCounterArrayDouble(hCounter pdhCounterHandle) ([]CounterValue, error) {
 	var buffSize uint32
 	var itemCount uint32
 	var ret uint32
 
-	if ret = PdhGetFormattedCounterArrayDouble(hCounter, &buffSize, &itemCount, nil); ret == PDH_MORE_DATA {
+	if ret = PdhGetFormattedCounterArrayDouble(hCounter, &buffSize, &itemCount, nil); ret == PdhMoreData {
 		buff := make([]byte, buffSize)
 
-		if ret = PdhGetFormattedCounterArrayDouble(hCounter, &buffSize, &itemCount, &buff[0]); ret == ERROR_SUCCESS {
+		if ret = PdhGetFormattedCounterArrayDouble(hCounter, &buffSize, &itemCount, &buff[0]); ret == ErrorSuccess {
 			//nolint:gosec // G103: Valid use of unsafe call to create PDH_FMT_COUNTERVALUE_ITEM_DOUBLE
-			items := (*[1 << 20]PDH_FMT_COUNTERVALUE_ITEM_DOUBLE)(unsafe.Pointer(&buff[0]))[:itemCount]
+			items := (*[1 << 20]PdhFmtCountervalueItemDouble)(unsafe.Pointer(&buff[0]))[:itemCount]
 			values := make([]CounterValue, 0, itemCount)
 			for _, item := range items {
-				if item.FmtValue.CStatus == PDH_CSTATUS_VALID_DATA || item.FmtValue.CStatus == PDH_CSTATUS_NEW_DATA {
+				if item.FmtValue.CStatus == PdhCstatusValidData || item.FmtValue.CStatus == PdhCstatusNewData {
 					val := CounterValue{UTF16PtrToString(item.SzName), item.FmtValue.DoubleValue}
 					values = append(values, val)
 				}
@@ -195,20 +195,20 @@ func (m *PerformanceQueryImpl) GetFormattedCounterArrayDouble(hCounter PDH_HCOUN
 	return nil, NewPdhError(ret)
 }
 
-func (m *PerformanceQueryImpl) GetRawCounterArray(hCounter PDH_HCOUNTER) ([]CounterValue, error) {
+func (m *PerformanceQueryImpl) GetRawCounterArray(hCounter pdhCounterHandle) ([]CounterValue, error) {
 	var buffSize uint32
 	var itemCount uint32
 	var ret uint32
 
-	if ret = PdhGetRawCounterArray(hCounter, &buffSize, &itemCount, nil); ret == PDH_MORE_DATA {
+	if ret = PdhGetRawCounterArray(hCounter, &buffSize, &itemCount, nil); ret == PdhMoreData {
 		buff := make([]byte, buffSize)
 
-		if ret = PdhGetRawCounterArray(hCounter, &buffSize, &itemCount, &buff[0]); ret == ERROR_SUCCESS {
+		if ret = PdhGetRawCounterArray(hCounter, &buffSize, &itemCount, &buff[0]); ret == ErrorSuccess {
 			//nolint:gosec // G103: Valid use of unsafe call to create PDH_RAW_COUNTER_ITEM
-			items := (*[1 << 20]PDH_RAW_COUNTER_ITEM)(unsafe.Pointer(&buff[0]))[:itemCount]
+			items := (*[1 << 20]PdhRawCounterItem)(unsafe.Pointer(&buff[0]))[:itemCount]
 			values := make([]CounterValue, 0, itemCount)
 			for _, item := range items {
-				if item.RawValue.CStatus == PDH_CSTATUS_VALID_DATA || item.RawValue.CStatus == PDH_CSTATUS_NEW_DATA {
+				if item.RawValue.CStatus == PdhCstatusValidData || item.RawValue.CStatus == PdhCstatusNewData {
 					val := CounterValue{UTF16PtrToString(item.SzName), item.RawValue.FirstValue}
 					values = append(values, val)
 				}
@@ -225,7 +225,7 @@ func (m *PerformanceQueryImpl) CollectData() error {
 		return errors.New("uninitialized query")
 	}
 
-	if ret = PdhCollectQueryData(m.query); ret != ERROR_SUCCESS {
+	if ret = PdhCollectQueryData(m.query); ret != ErrorSuccess {
 		return NewPdhError(ret)
 	}
 	return nil
@@ -236,7 +236,7 @@ func (m *PerformanceQueryImpl) CollectDataWithTime() (time.Time, error) {
 		return time.Now(), errors.New("uninitialized query")
 	}
 	ret, mtime := PdhCollectQueryDataWithTime(m.query)
-	if ret != ERROR_SUCCESS {
+	if ret != ErrorSuccess {
 		return time.Now(), NewPdhError(ret)
 	}
 	return mtime, nil
@@ -246,25 +246,22 @@ func (m *PerformanceQueryImpl) IsVistaOrNewer() bool {
 	return PdhAddEnglishCounterSupported()
 }
 
-func (m *PerformanceQueryImpl) GetRawCounterValue(hCounter PDH_HCOUNTER) (int64, error) {
+func (m *PerformanceQueryImpl) GetRawCounterValue(hCounter pdhCounterHandle) (int64, error) {
 	if m.query == 0 {
 		return 0, errors.New("uninitialised query")
 	}
 
 	var counterType uint32
-	var value PDH_RAW_COUNTER
+	var value PdhRawCounter
 	var ret uint32
 
-	if ret = PdhGetRawCounterValue(hCounter, &counterType, &value); ret == ERROR_SUCCESS {
-		if value.CStatus == PDH_CSTATUS_VALID_DATA || value.CStatus == PDH_CSTATUS_NEW_DATA {
+	if ret = PdhGetRawCounterValue(hCounter, &counterType, &value); ret == ErrorSuccess {
+		if value.CStatus == PdhCstatusValidData || value.CStatus == PdhCstatusNewData {
 			return value.FirstValue, nil
-		} else {
-			return 0, NewPdhError(value.CStatus)
 		}
-	} else {
-		return 0, NewPdhError(ret)
+		return 0, NewPdhError(value.CStatus)
 	}
-
+	return 0, NewPdhError(ret)
 }
 
 // UTF16PtrToString converts Windows API LPTSTR (pointer to string) to go string
