@@ -53,7 +53,7 @@ func (m *FakeSvcMgr) OpenService(name string) (WinService, error) {
 			}
 		}
 	}
-	return nil, fmt.Errorf("Cannot find service %s", name)
+	return nil, fmt.Errorf("cannot find service %q", name)
 }
 
 func (m *FakeSvcMgr) ListServices() ([]string, error) {
@@ -116,15 +116,15 @@ func (m *FakeWinSvc) Query() (svc.Status, error) {
 }
 
 var testErrors = []testData{
-	{nil, errors.New("Fake mgr connect error"), nil, nil},
-	{nil, nil, errors.New("Fake mgr list services error"), nil},
+	{nil, errors.New("fake mgr connect error"), nil, nil},
+	{nil, nil, errors.New("fake mgr list services error"), nil},
 	{[]string{"Fake service 1", "Fake service 2", "Fake service 3"}, nil, nil, []serviceTestInfo{
-		{errors.New("Fake srv open error"), nil, nil, "Fake service 1", "", 0, 0},
-		{nil, errors.New("Fake srv query error"), nil, "Fake service 2", "", 0, 0},
-		{nil, nil, errors.New("Fake srv config error"), "Fake service 3", "", 0, 0},
+		{errors.New("fake srv open error"), nil, nil, "Fake service 1", "", 0, 0},
+		{nil, errors.New("fake srv query error"), nil, "Fake service 2", "", 0, 0},
+		{nil, nil, errors.New("fake srv config error"), "Fake service 3", "", 0, 0},
 	}},
 	{[]string{"Fake service 1"}, nil, nil, []serviceTestInfo{
-		{errors.New("Fake srv open error"), nil, nil, "Fake service 1", "", 0, 0},
+		{errors.New("fake srv open error"), nil, nil, "Fake service 1", "", 0, 0},
 	}},
 }
 
@@ -155,9 +155,10 @@ func TestMgrErrors(t *testing.T) {
 		ServiceNames: []string{"Fake service 1"},
 		mgrProvider:  &FakeMgProvider{testErrors[3]},
 	}
-	winServices.Init()
-	var acc3 testutil.Accumulator
+	err = winServices.Init()
+	require.NoError(t, err)
 
+	var acc3 testutil.Accumulator
 	buf := &bytes.Buffer{}
 	log.SetOutput(buf)
 	require.NoError(t, winServices.Gather(&acc3))
@@ -170,9 +171,10 @@ func TestServiceErrors(t *testing.T) {
 		Log:         testutil.Logger{},
 		mgrProvider: &FakeMgProvider{testErrors[2]},
 	}
-	winServices.Init()
-	var acc1 testutil.Accumulator
+	err := winServices.Init()
+	require.NoError(t, err)
 
+	var acc1 testutil.Accumulator
 	buf := &bytes.Buffer{}
 	log.SetOutput(buf)
 	require.NoError(t, winServices.Gather(&acc1))
@@ -198,7 +200,10 @@ func TestGatherContainsTag(t *testing.T) {
 		ServiceNames: []string{"Service*"},
 		mgrProvider:  &FakeMgProvider{testSimpleData[0]},
 	}
-	winServices.Init()
+
+	err := winServices.Init()
+	require.NoError(t, err)
+
 	var acc1 testutil.Accumulator
 	require.NoError(t, winServices.Gather(&acc1))
 	require.Len(t, acc1.Errors, 0, "There should be no errors after gather")
@@ -206,8 +211,8 @@ func TestGatherContainsTag(t *testing.T) {
 	for _, s := range testSimpleData[0].services {
 		fields := make(map[string]interface{})
 		tags := make(map[string]string)
-		fields["state"] = int(s.state)
-		fields["startup_mode"] = int(s.startUpMode)
+		fields["state"] = s.state
+		fields["startup_mode"] = s.startUpMode
 		tags["service_name"] = s.serviceName
 		tags["display_name"] = s.displayName
 		acc1.AssertContainsTaggedFields(t, "win_services", fields, tags)
@@ -220,15 +225,17 @@ func TestExcludingNamesTag(t *testing.T) {
 		ServiceNamesExcluded: []string{"Service*"},
 		mgrProvider:          &FakeMgProvider{testSimpleData[0]},
 	}
-	winServices.Init()
+	err := winServices.Init()
+	require.NoError(t, err)
+
 	var acc1 testutil.Accumulator
 	require.NoError(t, winServices.Gather(&acc1))
 
 	for _, s := range testSimpleData[0].services {
 		fields := make(map[string]interface{})
 		tags := make(map[string]string)
-		fields["state"] = int(s.state)
-		fields["startup_mode"] = int(s.startUpMode)
+		fields["state"] = s.state
+		fields["startup_mode"] = s.startUpMode
 		tags["service_name"] = s.serviceName
 		tags["display_name"] = s.displayName
 		acc1.AssertDoesNotContainsTaggedFields(t, "win_services", fields, tags)
