@@ -8,6 +8,7 @@ import (
 	"crypto/tls"
 	"crypto/x509"
 	_ "embed"
+	"encoding/hex"
 	"encoding/pem"
 	"errors"
 	"fmt"
@@ -21,6 +22,7 @@ import (
 	"time"
 
 	"github.com/pion/dtls/v2"
+	"golang.org/x/crypto/ocsp"
 
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/config"
@@ -49,6 +51,8 @@ type X509Cert struct {
 	tlsCfg    *tls.Config
 	locations []*url.URL
 	globpaths []*globpath.GlobPath
+
+	classification map[string]string
 }
 
 func (*X509Cert) SampleConfig() string {
@@ -93,20 +97,28 @@ func (c *X509Cert) Gather(acc telegraf.Accumulator) error {
 
 	collectedUrls := append(c.locations, c.collectCertURLs()...)
 	for _, location := range collectedUrls {
-		certs, err := c.getCert(location, time.Duration(c.Timeout))
+		certs, ocspresp, err := c.getCert(location, time.Duration(c.Timeout))
 		if err != nil {
 			acc.AddError(fmt.Errorf("cannot get SSL cert %q: %w", location, err))
 		}
 
-		dnsName := c.serverName(location)
-		for i, cert := range certs {
-			fields := getFields(cert, now)
-			tags := getTags(cert, location.String())
+		// Add all returned certs to the pool of intermediates except for
+		// the leaf node which has to come first
+		intermediates := x509.NewCertPool()
+		if len(certs) > 1 {
+			for _, c := range certs[1:] {
+				intermediates.AddCert(c)
+			}
+		}
 
+		dnsName := c.serverName(location)
+		results := make([]error, 0, len(certs))
+		c.classification = make(map[string]string)
+		for _, cert := range certs {
 			// The first certificate is the leaf/end-entity certificate which
 			// needs DNS name validation against the URL hostname.
 			opts := x509.VerifyOptions{
-				Intermediates: x509.NewCertPool(),
+				Intermediates: intermediates,
 				KeyUsages:     []x509.ExtKeyUsage{x509.ExtKeyUsageAny},
 				Roots:         c.tlsCfg.RootCAs,
 				DNSName:       dnsName,
@@ -114,33 +126,81 @@ func (c *X509Cert) Gather(acc telegraf.Accumulator) error {
 			// Reset DNS name to only use it for the leaf node
 			dnsName = ""
 
-			// Add all returned certs to the pool if intermediates except for
-			// the leaf node and ourself
-			for j, c := range certs[1:] {
-				if i+1 != j {
-					opts.Intermediates.AddCert(c)
-				}
-			}
+			// Do the processing
+			results = append(results, c.processCertificate(cert, opts))
+		}
 
-			if _, err := cert.Verify(opts); err == nil {
+		for i, cert := range certs {
+			fields := getFields(cert, now)
+			tags := getTags(cert, location.String())
+
+			// Extract the verification result
+			err := results[i]
+			if err == nil {
 				tags["verification"] = "valid"
 				fields["verification_code"] = 0
 			} else {
-				c.Log.Debugf("Invalid certificate at index %2d!", i)
-				c.Log.Debugf("  cert DNS names:    %v", cert.DNSNames)
-				c.Log.Debugf("  cert IP addresses: %v", cert.IPAddresses)
-				c.Log.Debugf("  cert subject:      %v", cert.Subject)
-				c.Log.Debugf("  cert issuer:       %v", cert.Issuer)
-				c.Log.Debugf("  opts.DNSName:      %v", opts.DNSName)
-				c.Log.Debugf("  verify options:    %v", opts)
-				c.Log.Debugf("  verify error:      %v", err)
-				c.Log.Debugf("  location:          %v", location)
-				c.Log.Debugf("  tlsCfg.ServerName: %v", c.tlsCfg.ServerName)
-				c.Log.Debugf("  ServerName:        %v", c.ServerName)
 				tags["verification"] = "invalid"
 				fields["verification_code"] = 1
 				fields["verification_error"] = err.Error()
 			}
+			// OCSPResponse only for leaf cert
+			if i == 0 && ocspresp != nil && len(*ocspresp) > 0 {
+				var ocspissuer *x509.Certificate
+				for _, chaincert := range certs[1:] {
+					if cert.Issuer.CommonName == chaincert.Subject.CommonName &&
+						cert.Issuer.SerialNumber == chaincert.Subject.SerialNumber {
+						ocspissuer = chaincert
+						break
+					}
+				}
+				resp, err := ocsp.ParseResponse(*ocspresp, ocspissuer)
+				if err != nil {
+					if ocspissuer == nil {
+						tags["ocsp_stapled"] = "no"
+						fields["ocsp_error"] = err.Error()
+					} else {
+						ocspissuer = nil // retry parsing w/out issuer cert
+						resp, err = ocsp.ParseResponse(*ocspresp, ocspissuer)
+					}
+				}
+				if err != nil {
+					tags["ocsp_stapled"] = "no"
+					fields["ocsp_error"] = err.Error()
+				} else {
+					tags["ocsp_stapled"] = "yes"
+					if ocspissuer != nil {
+						tags["ocsp_verified"] = "yes"
+					} else {
+						tags["ocsp_verified"] = "no"
+					}
+					// resp.Status: 0=Good 1=Revoked 2=Unknown
+					fields["ocsp_status_code"] = resp.Status
+					switch resp.Status {
+					case 0:
+						tags["ocsp_status"] = "good"
+					case 1:
+						tags["ocsp_status"] = "revoked"
+						// Status=Good: revoked_at always = -62135596800
+						fields["ocsp_revoked_at"] = resp.RevokedAt.Unix()
+					default:
+						tags["ocsp_status"] = "unknown"
+					}
+					fields["ocsp_produced_at"] = resp.ProducedAt.Unix()
+					fields["ocsp_this_update"] = resp.ThisUpdate.Unix()
+					fields["ocsp_next_update"] = resp.NextUpdate.Unix()
+				}
+			} else {
+				tags["ocsp_stapled"] = "no"
+			}
+
+			// Determine the classification
+			sig := hex.EncodeToString(cert.Signature)
+			if class, found := c.classification[sig]; found {
+				tags["type"] = class
+			} else {
+				tags["type"] = "leaf"
+			}
 
 			acc.AddFields("x509_cert", fields, tags)
 			if c.ExcludeRootCerts {
@@ -152,6 +212,66 @@ func (c *X509Cert) Gather(acc telegraf.Accumulator) error {
 	return nil
 }
 
+func (c *X509Cert) processCertificate(certificate *x509.Certificate, opts x509.VerifyOptions) error {
+	chains, err := certificate.Verify(opts)
+	if err != nil {
+		c.Log.Debugf("Invalid certificate %v", certificate.SerialNumber.Text(16))
+		c.Log.Debugf("  cert DNS names:    %v", certificate.DNSNames)
+		c.Log.Debugf("  cert IP addresses: %v", certificate.IPAddresses)
+		c.Log.Debugf("  cert subject:      %v", certificate.Subject)
+		c.Log.Debugf("  cert issuer:       %v", certificate.Issuer)
+		c.Log.Debugf("  opts.DNSName:      %v", opts.DNSName)
+		c.Log.Debugf("  verify options:    %v", opts)
+		c.Log.Debugf("  verify error:      %v", err)
+		c.Log.Debugf("  tlsCfg.ServerName: %v", c.tlsCfg.ServerName)
+		c.Log.Debugf("  ServerName:        %v", c.ServerName)
+	}
+
+	// Check if the certificate is a root-certificate.
+	// The only reliable way to distinguish root certificates from
+	// intermediates is the fact that root certificates are self-signed,
+	// i.e. you can verify the certificate with its own public key.
+	rootErr := certificate.CheckSignature(certificate.SignatureAlgorithm, certificate.RawTBSCertificate, certificate.Signature)
+	if rootErr == nil {
+		sig := hex.EncodeToString(certificate.Signature)
+		c.classification[sig] = "root"
+	}
+
+	// Identify intermediate certificates
+	for _, chain := range chains {
+		// All nodes except the first one are of intermediate or CA type.
+		// Mark them as such. We never add leaf nodes to the classification
+		// so in the end if a cert is NOT in the classification it is a true
+		// leaf node.
+		for _, cert := range chain[1:] {
+			// Never change a classification if we already have one
+			sig := hex.EncodeToString(cert.Signature)
+			if _, found := c.classification[sig]; found {
+				continue
+			}
+
+			// We found an intermediate certificate which is not a CA. This
+			// should never happen actually.
+			if !cert.IsCA {
+				c.classification[sig] = "unknown"
+				continue
+			}
+
+			// The only reliable way to distinguish root certificates from
+			// intermediates is the fact that root certificates are self-signed,
+			// i.e. you can verify the certificate with its own public key.
+			rootErr := cert.CheckSignature(cert.SignatureAlgorithm, cert.RawTBSCertificate, cert.Signature)
+			if rootErr != nil {
+				c.classification[sig] = "intermediate"
+			} else {
+				c.classification[sig] = "root"
+			}
+		}
+	}
+
+	return err
+}
+
 func (c *X509Cert) sourcesToURLs() error {
 	for _, source := range c.Sources {
 		if strings.HasPrefix(source, "file://") || strings.HasPrefix(source, "/") {
@@ -161,7 +281,7 @@ func (c *X509Cert) sourcesToURLs() error {
 			source = reDriveLetter.ReplaceAllString(source, "$1")
 			g, err := globpath.Compile(source)
 			if err != nil {
-				return fmt.Errorf("could not compile glob %v: %v", source, err)
+				return fmt.Errorf("could not compile glob %q: %w", source, err)
 			}
 			c.globpaths = append(c.globpaths, g)
 		} else {
@@ -170,7 +290,7 @@ func (c *X509Cert) sourcesToURLs() error {
 			}
 			u, err := url.Parse(source)
 			if err != nil {
-				return fmt.Errorf("failed to parse cert location - %s", err.Error())
+				return fmt.Errorf("failed to parse cert location: %w", err)
 			}
 			c.locations = append(c.locations, u)
 		}
@@ -186,13 +306,13 @@ func (c *X509Cert) serverName(u *url.URL) string {
 	return u.Hostname()
 }
 
-func (c *X509Cert) getCert(u *url.URL, timeout time.Duration) ([]*x509.Certificate, error) {
+func (c *X509Cert) getCert(u *url.URL, timeout time.Duration) ([]*x509.Certificate, *[]byte, error) {
 	protocol := u.Scheme
 	switch u.Scheme {
 	case "udp", "udp4", "udp6":
 		ipConn, err := net.DialTimeout(u.Scheme, u.Host, timeout)
 		if err != nil {
-			return nil, err
+			return nil, nil, err
 		}
 		defer ipConn.Close()
 
@@ -204,7 +324,7 @@ func (c *X509Cert) getCert(u *url.URL, timeout time.Duration) ([]*x509.Certifica
 		}
 		conn, err := dtls.Client(ipConn, dtlsCfg)
 		if err != nil {
-			return nil, err
+			return nil, nil, err
 		}
 		defer conn.Close()
 
@@ -213,7 +333,7 @@ func (c *X509Cert) getCert(u *url.URL, timeout time.Duration) ([]*x509.Certifica
 		for _, rawCert := range rawCerts {
 			parsed, err := x509.ParseCertificate(rawCert)
 			if err != nil {
-				return nil, err
+				return nil, nil, err
 			}
 
 			if parsed != nil {
@@ -221,7 +341,7 @@ func (c *X509Cert) getCert(u *url.URL, timeout time.Duration) ([]*x509.Certifica
 			}
 		}
 
-		return certs, nil
+		return certs, nil, nil
 	case "https":
 		protocol = "tcp"
 		if u.Port() == "" {
@@ -231,11 +351,11 @@ func (c *X509Cert) getCert(u *url.URL, timeout time.Duration) ([]*x509.Certifica
 	case "tcp", "tcp4", "tcp6":
 		dialer, err := c.Proxy()
 		if err != nil {
-			return nil, err
+			return nil, nil, err
 		}
 		ipConn, err := dialer.DialTimeout(protocol, u.Host, timeout)
 		if err != nil {
-			return nil, err
+			return nil, nil, err
 		}
 		defer ipConn.Close()
 
@@ -248,28 +368,29 @@ func (c *X509Cert) getCert(u *url.URL, timeout time.Duration) ([]*x509.Certifica
 
 		hsErr := conn.Handshake()
 		if hsErr != nil {
-			return nil, hsErr
+			return nil, nil, hsErr
 		}
 
 		certs := conn.ConnectionState().PeerCertificates
+		ocspresp := conn.ConnectionState().OCSPResponse
 
-		return certs, nil
+		return certs, &ocspresp, nil
 	case "file":
 		content, err := os.ReadFile(u.Path)
 		if err != nil {
-			return nil, err
+			return nil, nil, err
 		}
 		var certs []*x509.Certificate
 		for {
 			block, rest := pem.Decode(bytes.TrimSpace(content))
 			if block == nil {
-				return nil, fmt.Errorf("failed to parse certificate PEM")
+				return nil, nil, fmt.Errorf("failed to parse certificate PEM")
 			}
 
 			if block.Type == "CERTIFICATE" {
 				cert, err := x509.ParseCertificate(block.Bytes)
 				if err != nil {
-					return nil, err
+					return nil, nil, err
 				}
 				certs = append(certs, cert)
 			}
@@ -278,11 +399,11 @@ func (c *X509Cert) getCert(u *url.URL, timeout time.Duration) ([]*x509.Certifica
 			}
 			content = rest
 		}
-		return certs, nil
+		return certs, nil, nil
 	case "smtp":
 		ipConn, err := net.DialTimeout("tcp", u.Host, timeout)
 		if err != nil {
-			return nil, err
+			return nil, nil, err
 		}
 		defer ipConn.Close()
 
@@ -292,24 +413,24 @@ func (c *X509Cert) getCert(u *url.URL, timeout time.Duration) ([]*x509.Certifica
 
 		smtpConn, err := smtp.NewClient(ipConn, u.Host)
 		if err != nil {
-			return nil, err
+			return nil, nil, err
 		}
 
 		err = smtpConn.Hello(downloadTLSCfg.ServerName)
 		if err != nil {
-			return nil, err
+			return nil, nil, err
 		}
 
 		id, err := smtpConn.Text.Cmd("STARTTLS")
 		if err != nil {
-			return nil, err
+			return nil, nil, err
 		}
 
 		smtpConn.Text.StartResponse(id)
 		defer smtpConn.Text.EndResponse(id)
 		_, _, err = smtpConn.Text.ReadResponse(220)
 		if err != nil {
-			return nil, fmt.Errorf("did not get 220 after STARTTLS: %s", err.Error())
+			return nil, nil, fmt.Errorf("did not get 220 after STARTTLS: %w", err)
 		}
 
 		tlsConn := tls.Client(ipConn, downloadTLSCfg)
@@ -317,14 +438,15 @@ func (c *X509Cert) getCert(u *url.URL, timeout time.Duration) ([]*x509.Certifica
 
 		hsErr := tlsConn.Handshake()
 		if hsErr != nil {
-			return nil, hsErr
+			return nil, nil, hsErr
 		}
 
 		certs := tlsConn.ConnectionState().PeerCertificates
+		ocspresp := tlsConn.ConnectionState().OCSPResponse
 
-		return certs, nil
+		return certs, &ocspresp, nil
 	default:
-		return nil, fmt.Errorf("unsupported scheme %q in location %s", u.Scheme, u.String())
+		return nil, nil, fmt.Errorf("unsupported scheme %q in location %s", u.Scheme, u.String())
 	}
 }
 
