@@ -5,8 +5,8 @@ import (
 	_ "embed"
 	"fmt"
 	"math"
+	"strconv"
 	"time"
-	"unsafe"
 
 	"github.com/microsoft/ApplicationInsights-Go/appinsights"
 
@@ -40,11 +40,6 @@ type ApplicationInsights struct {
 	diagMsgListener   appinsights.DiagnosticsMessageListener
 }
 
-var (
-	is32Bit        bool
-	is32BitChecked bool
-)
-
 func (*ApplicationInsights) SampleConfig() string {
 	return sampleConfig
 }
@@ -281,20 +276,10 @@ func toFloat64(value interface{}) (float64, error) {
 }
 
 func toInt(value interface{}) (int, error) {
-	if !is32BitChecked {
-		is32BitChecked = true
-		var i int
-		if unsafe.Sizeof(i) == 4 {
-			is32Bit = true
-		} else {
-			is32Bit = false
-		}
-	}
-
 	// Out of all Golang numerical types Telegraf only uses int64, unit64 and float64 for fields
 	switch v := value.(type) {
 	case uint64:
-		if is32Bit {
+		if strconv.IntSize == 32 {
 			if v > math.MaxInt32 {
 				return 0, fmt.Errorf("value [%d] out of range of 32-bit integers", v)
 			}
@@ -307,7 +292,7 @@ func toInt(value interface{}) (int, error) {
 		return int(v), nil
 
 	case int64:
-		if is32Bit {
+		if strconv.IntSize == 32 {
 			if v > math.MaxInt32 || v < math.MinInt32 {
 				return 0, fmt.Errorf("value [%d] out of range of 32-bit integers", v)
 			}
