@@ -16,6 +16,7 @@ import (
 	"time"
 
 	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/internal"
 	"github.com/influxdata/telegraf/plugins/serializers/influx"
 )
@@ -41,7 +42,7 @@ const (
 
 type HTTPConfig struct {
 	URL              *url.URL
-	Token            string
+	Token            config.Secret
 	Organization     string
 	Bucket           string
 	BucketTag        string
@@ -74,59 +75,66 @@ type httpClient struct {
 	log        telegraf.Logger
 }
 
-func NewHTTPClient(config *HTTPConfig) (*httpClient, error) {
-	if config.URL == nil {
+func NewHTTPClient(cfg *HTTPConfig) (*httpClient, error) {
+	if cfg.URL == nil {
 		return nil, ErrMissingURL
 	}
 
-	timeout := config.Timeout
+	timeout := cfg.Timeout
 	if timeout == 0 {
 		timeout = defaultRequestTimeout
 	}
 
-	userAgent := config.UserAgent
+	userAgent := cfg.UserAgent
 	if userAgent == "" {
 		userAgent = internal.ProductToken()
 	}
 
-	var headers = make(map[string]string, len(config.Headers)+2)
+	var headers = make(map[string]string, len(cfg.Headers)+2)
 	headers["User-Agent"] = userAgent
-	headers["Authorization"] = "Token " + config.Token
-	for k, v := range config.Headers {
+
+	token, err := cfg.Token.Get()
+	if err != nil {
+		return nil, fmt.Errorf("getting token failed: %w", err)
+	}
+	headers["Authorization"] = "Token " + string(token)
+	config.ReleaseSecret(token)
+
+	for k, v := range cfg.Headers {
 		headers[k] = v
 	}
 
 	var proxy func(*http.Request) (*url.URL, error)
-	if config.Proxy != nil {
-		proxy = http.ProxyURL(config.Proxy)
+	if cfg.Proxy != nil {
+		proxy = http.ProxyURL(cfg.Proxy)
 	} else {
 		proxy = http.ProxyFromEnvironment
 	}
 
-	serializer := config.Serializer
+	serializer := cfg.Serializer
 	if serializer == nil {
 		serializer = influx.NewSerializer()
 	}
 
 	var transport *http.Transport
-	switch config.URL.Scheme {
+	switch cfg.URL.Scheme {
 	case "http", "https":
 		transport = &http.Transport{
 			Proxy:           proxy,
-			TLSClientConfig: config.TLSConfig,
+			TLSClientConfig: cfg.TLSConfig,
 		}
 	case "unix":
 		transport = &http.Transport{
 			Dial: func(_, _ string) (net.Conn, error) {
 				return net.DialTimeout(
-					config.URL.Scheme,
-					config.URL.Path,
+					cfg.URL.Scheme,
+					cfg.URL.Path,
 					timeout,
 				)
 			},
 		}
 	default:
-		return nil, fmt.Errorf("unsupported scheme %q", config.URL.Scheme)
+		return nil, fmt.Errorf("unsupported scheme %q", cfg.URL.Scheme)
 	}
 
 	client := &httpClient{
@@ -135,15 +143,15 @@ func NewHTTPClient(config *HTTPConfig) (*httpClient, error) {
 			Timeout:   timeout,
 			Transport: transport,
 		},
-		url:              config.URL,
-		ContentEncoding:  config.ContentEncoding,
+		url:              cfg.URL,
+		ContentEncoding:  cfg.ContentEncoding,
 		Timeout:          timeout,
 		Headers:          headers,
-		Organization:     config.Organization,
-		Bucket:           config.Bucket,
-		BucketTag:        config.BucketTag,
-		ExcludeBucketTag: config.ExcludeBucketTag,
-		log:              config.Log,
+		Organization:     cfg.Organization,
+		Bucket:           cfg.Bucket,
+		BucketTag:        cfg.BucketTag,
+		ExcludeBucketTag: cfg.ExcludeBucketTag,
+		log:              cfg.Log,
 	}
 	return client, nil
 }
