@@ -25,10 +25,10 @@ const (
 )
 
 type Logzio struct {
-	Log     telegraf.Logger `toml:"-"`
-	Timeout config.Duration `toml:"timeout"`
-	Token   string          `toml:"token"`
 	URL     string          `toml:"url"`
+	Token   config.Secret   `toml:"token"`
+	Timeout config.Duration `toml:"timeout"`
+	Log     telegraf.Logger `toml:"-"`
 
 	tls.ClientConfig
 	client *http.Client
@@ -53,9 +53,14 @@ func (*Logzio) SampleConfig() string {
 func (l *Logzio) Connect() error {
 	l.Log.Debug("Connecting to logz.io output...")
 
-	if l.Token == "" || l.Token == "your logz.io token" {
+	if l.Token.Empty() {
 		return fmt.Errorf("token is required")
 	}
+	if equal, err := l.Token.EqualTo([]byte("your logz.io token")); err != nil {
+		return err
+	} else if equal {
+		return fmt.Errorf("please replace 'token' with your actual token")
+	}
 
 	tlsCfg, err := l.ClientConfig.TLSConfig()
 	if err != nil {
@@ -110,7 +115,12 @@ func (l *Logzio) Write(metrics []telegraf.Metric) error {
 }
 
 func (l *Logzio) send(metrics []byte) error {
-	req, err := http.NewRequest("POST", l.authURL(), bytes.NewBuffer(metrics))
+	url, err := l.authURL()
+	if err != nil {
+		return err
+	}
+
+	req, err := http.NewRequest("POST", url, bytes.NewBuffer(metrics))
 	if err != nil {
 		return fmt.Errorf("unable to create http.Request: %w", err)
 	}
@@ -130,8 +140,14 @@ func (l *Logzio) send(metrics []byte) error {
 	return nil
 }
 
-func (l *Logzio) authURL() string {
-	return fmt.Sprintf("%s/?token=%s", l.URL, l.Token)
+func (l *Logzio) authURL() (string, error) {
+	token, err := l.Token.Get()
+	if err != nil {
+		return "", fmt.Errorf("getting token failed: %w", err)
+	}
+	defer config.ReleaseSecret(token)
+
+	return fmt.Sprintf("%s/?token=%s", l.URL, string(token)), nil
 }
 
 func (l *Logzio) parseMetric(metric telegraf.Metric) *Metric {
