@@ -12,7 +12,6 @@ import (
 	"github.com/influxdata/telegraf/plugins/serializers"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
 //go:embed sample.conf
 var sampleConfig string
 
@@ -64,7 +63,7 @@ func (n *NSQ) Write(metrics []telegraf.Metric) error {
 
 		err = n.producer.Publish(n.Topic, buf)
 		if err != nil {
-			return fmt.Errorf("failed to send NSQD message: %s", err)
+			return fmt.Errorf("failed to send NSQD message: %w", err)
 		}
 	}
 	return nil
