@@ -1,14 +1,15 @@
+//go:generate ../../../tools/readme_config_includer/generator
 package sumologic
 
 import (
 	"bytes"
 	"compress/gzip"
-	"log"
+	_ "embed"
+	"errors"
+	"fmt"
 	"net/http"
 	"time"
 
-	"github.com/pkg/errors"
-
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/internal"
@@ -19,59 +20,10 @@ import (
 	"github.com/influxdata/telegraf/plugins/serializers/prometheus"
 )
 
+//go:embed sample.conf
+var sampleConfig string
+
 const (
-	sampleConfig = `
-  ## Unique URL generated for your HTTP Metrics Source.
-  ## This is the address to send metrics to.
-  # url = "https://events.sumologic.net/receiver/v1/http/<UniqueHTTPCollectorCode>"
-
-  ## Data format to be used for sending metrics.
-  ## This will set the "Content-Type" header accordingly.
-  ## Currently supported formats:
-  ## * graphite - for Content-Type of application/vnd.sumologic.graphite
-  ## * carbon2 - for Content-Type of application/vnd.sumologic.carbon2
-  ## * prometheus - for Content-Type of application/vnd.sumologic.prometheus
-  ##
-  ## More information can be found at:
-  ## https://help.sumologic.com/03Send-Data/Sources/02Sources-for-Hosted-Collectors/HTTP-Source/Upload-Metrics-to-an-HTTP-Source#content-type-headers-for-metrics
-  ##
-  ## NOTE:
-  ## When unset, telegraf will by default use the influx serializer which is currently unsupported
-  ## in HTTP Source.
-  data_format = "carbon2"
-
-  ## Timeout used for HTTP request
-  # timeout = "5s"
-
-  ## Max HTTP request body size in bytes before compression (if applied).
-  ## By default 1MB is recommended.
-  ## NOTE:
-  ## Bear in mind that in some serializer a metric even though serialized to multiple
-  ## lines cannot be split any further so setting this very low might not work
-  ## as expected.
-  # max_request_body_size = 1000000
-
-  ## Additional, Sumo specific options.
-  ## Full list can be found here:
-  ## https://help.sumologic.com/03Send-Data/Sources/02Sources-for-Hosted-Collectors/HTTP-Source/Upload-Metrics-to-an-HTTP-Source#supported-http-headers
-
-  ## Desired source name.
-  ## Useful if you want to override the source name configured for the source.
-  # source_name = ""
-
-  ## Desired host name.
-  ## Useful if you want to override the source host configured for the source.
-  # source_host = ""
-
-  ## Desired source category.
-  ## Useful if you want to override the source category configured for the source.
-  # source_category = ""
-
-  ## Comma-separated key=value list of dimensions to apply to every metric.
-  ## Custom dimensions will allow you to query your metrics at a more granular level.
-  # dimensions = ""
-`
-
 	defaultClientTimeout      = 5 * time.Second
 	defaultMethod             = http.MethodPost
 	defaultMaxRequestBodySize = 1000000
@@ -110,6 +62,10 @@ type SumoLogic struct {
 	headers map[string]string
 }
 
+func (*SumoLogic) SampleConfig() string {
+	return sampleConfig
+}
+
 func (s *SumoLogic) SetSerializer(serializer serializers.Serializer) {
 	if s.headers == nil {
 		s.headers = make(map[string]string)
@@ -132,7 +88,7 @@ func (s *SumoLogic) SetSerializer(serializer serializers.Serializer) {
 		s.headers[contentTypeHeader] = prometheusContentType
 
 	default:
-		s.err = errors.Errorf("unsupported serializer %T", serializer)
+		s.err = fmt.Errorf("unsupported serializer %T", serializer)
 	}
 
 	s.serializer = serializer
@@ -149,7 +105,7 @@ func (s *SumoLogic) createClient() *http.Client {
 
 func (s *SumoLogic) Connect() error {
 	if s.err != nil {
-		return errors.Wrap(s.err, "sumologic: incorrect configuration")
+		return fmt.Errorf("sumologic: incorrect configuration: %w", s.err)
 	}
 
 	if s.Timeout == 0 {
@@ -165,17 +121,9 @@ func (s *SumoLogic) Close() error {
 	return s.err
 }
 
-func (s *SumoLogic) Description() string {
-	return "A plugin that can transmit metrics to Sumo Logic HTTP Source"
-}
-
-func (s *SumoLogic) SampleConfig() string {
-	return sampleConfig
-}
-
 func (s *SumoLogic) Write(metrics []telegraf.Metric) error {
 	if s.err != nil {
-		return errors.Wrap(s.err, "sumologic: incorrect configuration")
+		return fmt.Errorf("sumologic: incorrect configuration: %w", s.err)
 	}
 	if s.serializer == nil {
 		return errors.New("sumologic: serializer unset")
@@ -198,19 +146,19 @@ func (s *SumoLogic) Write(metrics []telegraf.Metric) error {
 		return s.writeRequestChunks(chunks)
 	}
 
-	return s.write(reqBody)
+	return s.writeRequestChunk(reqBody)
 }
 
 func (s *SumoLogic) writeRequestChunks(chunks [][]byte) error {
 	for _, reqChunk := range chunks {
-		if err := s.write(reqChunk); err != nil {
+		if err := s.writeRequestChunk(reqChunk); err != nil {
 			s.Log.Errorf("Error sending chunk: %v", err)
 		}
 	}
 	return nil
 }
 
-func (s *SumoLogic) write(reqBody []byte) error {
+func (s *SumoLogic) writeRequestChunk(reqBody []byte) error {
 	var (
 		err  error
 		buff bytes.Buffer
@@ -245,15 +193,12 @@ func (s *SumoLogic) write(reqBody []byte) error {
 
 	resp, err := s.client.Do(req)
 	if err != nil {
-		return errors.Wrapf(err, "sumologic: failed sending request to [%s]", s.URL)
+		return fmt.Errorf("sumologic: failed sending request to %q: %w", s.URL, err)
 	}
 	defer resp.Body.Close()
 
 	if resp.StatusCode < 200 || resp.StatusCode >= 300 {
-		return errors.Errorf(
-			"sumologic: when writing to [%s] received status code: %d",
-			s.URL, resp.StatusCode,
-		)
+		return fmt.Errorf("sumologic: when writing to %q received status code: %d", s.URL, resp.StatusCode)
 	}
 
 	return nil
@@ -284,31 +229,31 @@ func (s *SumoLogic) splitIntoChunks(metrics []telegraf.Metric) ([][]byte, error)
 				if la+len(chunkBody) > int(s.MaxRequstBodySize) {
 					// ... and it's just the right size, without currently processed chunk.
 					break
-				} else {
-					// ... we can try appending more.
-					i++
-					toAppend = append(toAppend, chunkBody...)
-					continue
 				}
-			} else { // la == 0
+				// ... we can try appending more.
 				i++
-				toAppend = chunkBody
-
-				if len(chunkBody) > int(s.MaxRequstBodySize) {
-					log.Printf(
-						"W! [SumoLogic] max_request_body_size set to %d which is too small even for a single metric (len: %d), sending without split",
-						s.MaxRequstBodySize, len(chunkBody),
-					)
-
-					// The serialized metric is too big but we have no choice
-					// but to send it.
-					// max_request_body_size was set so small that it wouldn't
-					// even accomodate a single metric.
-					break
-				}
-
+				toAppend = append(toAppend, chunkBody...)
 				continue
 			}
+
+			// la == 0
+			i++
+			toAppend = chunkBody
+
+			if len(chunkBody) > int(s.MaxRequstBodySize) {
+				s.Log.Warnf(
+					"max_request_body_size set to %d which is too small even for a single metric (len: %d), sending without split",
+					s.MaxRequstBodySize, len(chunkBody),
+				)
+
+				// The serialized metric is too big, but we have no choice
+				// but to send it.
+				// max_request_body_size was set so small that it wouldn't
+				// even accommodate a single metric.
+				break
+			}
+
+			continue
 		}
 
 		if toAppend == nil {
