@@ -52,6 +52,7 @@ type Parser struct {
 	Log                telegraf.Logger `toml:"-"`
 
 	metadataSeparatorList metadataPattern
+	location              *time.Location
 
 	gotColumnNames bool
 
@@ -170,6 +171,14 @@ func (p *Parser) Init() error {
 		p.TimeFunc = time.Now
 	}
 
+	if p.Timezone != "" {
+		loc, err := time.LoadLocation(p.Timezone)
+		if err != nil {
+			return fmt.Errorf("invalid timezone: %w", err)
+		}
+		p.location = loc
+	}
+
 	if p.ResetMode == "" {
 		p.ResetMode = "none"
 	}
@@ -446,7 +455,7 @@ outer:
 		}
 	}
 
-	metricTime, err := parseTimestamp(p.TimeFunc, recordFields, p.TimestampColumn, p.TimestampFormat, p.Timezone)
+	metricTime, err := parseTimestamp(p.TimeFunc, recordFields, p.TimestampColumn, p.TimestampFormat, p.location)
 	if err != nil {
 		return nil, err
 	}
@@ -464,7 +473,7 @@ outer:
 // will be the current timestamp, else it will try to parse the time according
 // to the format.
 func parseTimestamp(timeFunc func() time.Time, recordFields map[string]interface{},
-	timestampColumn, timestampFormat string, timezone string,
+	timestampColumn, timestampFormat string, timezone *time.Location,
 ) (time.Time, error) {
 	if timestampColumn != "" {
 		if recordFields[timestampColumn] == nil {
