@@ -36,6 +36,7 @@ type Parser struct {
 	DefaultTags map[string]string `toml:"-"`
 	Log         telegraf.Logger   `toml:"-"`
 
+	location     *time.Location
 	tagFilter    filter.Filter
 	stringFilter filter.Filter
 }
@@ -95,7 +96,7 @@ func (p *Parser) parseObject(data map[string]interface{}, timestamp time.Time) (
 			return nil, err
 		}
 
-		timestamp, err = internal.ParseTimestamp(p.TimeFormat, f.Fields[p.TimeKey], p.Timezone)
+		timestamp, err = internal.ParseTimestamp(p.TimeFormat, f.Fields[p.TimeKey], p.location)
 		if err != nil {
 			return nil, err
 		}
@@ -169,6 +170,14 @@ func (p *Parser) Init() error {
 		return fmt.Errorf("compiling tag-key filter failed: %w", err)
 	}
 
+	if p.Timezone != "" {
+		loc, err := time.LoadLocation(p.Timezone)
+		if err != nil {
+			return fmt.Errorf("invalid timezone: %w", err)
+		}
+		p.location = loc
+	}
+
 	return nil
 }
 
