@@ -26,7 +26,7 @@ type Parser struct {
 
 	// **** The struct fields bellow this comment are used for processing indvidual configs ****
 
-	// measurementName is the the name of the current config used in each line protocol
+	// measurementName is the name of the current config used in each line protocol
 	measurementName string
 
 	// **** Specific for object configuration ****
@@ -66,6 +66,13 @@ func (p *Parser) Init() error {
 		if cfg.MeasurementName == "" {
 			p.Configs[i].MeasurementName = p.DefaultMetricName
 		}
+		if cfg.TimestampTimezone != "" {
+			loc, err := time.LoadLocation(cfg.TimestampTimezone)
+			if err != nil {
+				return fmt.Errorf("invalid timezone in config %d: %w", i+1, err)
+			}
+			p.Configs[i].Location = loc
+		}
 	}
 	return nil
 }
@@ -75,12 +82,12 @@ func (p *Parser) Parse(input []byte) ([]telegraf.Metric, error) {
 	body, _ := utfbom.Skip(reader)
 	input, err := io.ReadAll(body)
 	if err != nil {
-		return nil, fmt.Errorf("unable to read body after BOM removal: %v", err)
+		return nil, fmt.Errorf("unable to read body after BOM removal: %w", err)
 	}
 
 	// Only valid JSON is supported
 	if !gjson.Valid(string(input)) {
-		return nil, fmt.Errorf("invalid JSON provided, unable to parse")
+		return nil, fmt.Errorf("invalid JSON provided, unable to parse: %s", string(input))
 	}
 
 	var metrics []telegraf.Metric
@@ -102,7 +109,7 @@ func (p *Parser) Parse(input []byte) ([]telegraf.Metric, error) {
 
 			if result.Type == gjson.Null {
 				p.Log.Debugf("Message: %s", input)
-				return nil, fmt.Errorf("The timestamp path %s returned NULL", c.TimestampPath)
+				return nil, fmt.Errorf("the timestamp path %s returned NULL", c.TimestampPath)
 			}
 			if !result.IsArray() && !result.IsObject() {
 				if c.TimestampFormat == "" {
@@ -111,7 +118,7 @@ func (p *Parser) Parse(input []byte) ([]telegraf.Metric, error) {
 				}
 
 				var err error
-				timestamp, err = internal.ParseTimestamp(c.TimestampFormat, result.String(), c.TimestampTimezone)
+				timestamp, err = internal.ParseTimestamp(c.TimestampFormat, result.String(), c.Location)
 
 				if err != nil {
 					return nil, err
@@ -161,8 +168,7 @@ func (p *Parser) processMetric(input []byte, data []json_v2.DataSet, tag bool, t
 	}
 
 	p.iterateObjects = false
-	var metrics [][]telegraf.Metric
-
+	metrics := make([][]telegraf.Metric, 0, len(data))
 	for _, c := range data {
 		if c.Path == "" {
 			return nil, fmt.Errorf("GJSON path is required")
@@ -230,14 +236,12 @@ func cartesianProduct(a, b []telegraf.Metric) []telegraf.Metric {
 	if len(b) == 0 {
 		return a
 	}
-	p := make([]telegraf.Metric, len(a)*len(b))
-	i := 0
+	p := make([]telegraf.Metric, 0, len(a)*len(b))
 	for _, a := range a {
 		for _, b := range b {
 			m := a.Copy()
 			mergeMetric(b, m)
-			p[i] = m
-			i++
+			p = append(p, m)
 		}
 	}
 
@@ -324,7 +328,15 @@ func (p *Parser) expandArray(result MetricNode, timestamp time.Time) ([]telegraf
 				err := fmt.Errorf("use of 'timestamp_query' requires 'timestamp_format'")
 				return nil, err
 			}
-			timestamp, err := internal.ParseTimestamp(p.objectConfig.TimestampFormat, result.String(), p.objectConfig.TimestampTimezone)
+			var loc *time.Location
+			if p.objectConfig.TimestampTimezone != "" {
+				var err error
+				loc, err = time.LoadLocation(p.objectConfig.TimestampTimezone)
+				if err != nil {
+					return nil, fmt.Errorf("invalid timezone: %w", err)
+				}
+			}
+			timestamp, err := internal.ParseTimestamp(p.objectConfig.TimestampFormat, result.String(), loc)
 			if err != nil {
 				return nil, err
 			}
@@ -573,7 +585,7 @@ func (p *Parser) isExcluded(key string) bool {
 	return false
 }
 
-func (p *Parser) ParseLine(line string) (telegraf.Metric, error) {
+func (p *Parser) ParseLine(_ string) (telegraf.Metric, error) {
 	return nil, fmt.Errorf("ParseLine is designed for parsing influx line protocol, therefore not implemented for parsing JSON")
 }
 
@@ -589,25 +601,25 @@ func (p *Parser) convertType(input gjson.Result, desiredType string, name string
 		case "uint":
 			r, err := strconv.ParseUint(inputType, 10, 64)
 			if err != nil {
-				return nil, fmt.Errorf("Unable to convert field '%s' to type uint: %v", name, err)
+				return nil, fmt.Errorf("unable to convert field %q to type uint: %w", name, err)
 			}
 			return r, nil
 		case "int":
 			r, err := strconv.ParseInt(inputType, 10, 64)
 			if err != nil {
-				return nil, fmt.Errorf("Unable to convert field '%s' to type int: %v", name, err)
+				return nil, fmt.Errorf("unable to convert field %q to type int: %w", name, err)
 			}
 			return r, nil
 		case "float":
 			r, err := strconv.ParseFloat(inputType, 64)
 			if err != nil {
-				return nil, fmt.Errorf("Unable to convert field '%s' to type float: %v", name, err)
+				return nil, fmt.Errorf("unable to convert field %q to type float: %w", name, err)
 			}
 			return r, nil
 		case "bool":
 			r, err := strconv.ParseBool(inputType)
 			if err != nil {
-				return nil, fmt.Errorf("Unable to convert field '%s' to type bool: %v", name, err)
+				return nil, fmt.Errorf("unable to convert field %q to type bool: %w", name, err)
 			}
 			return r, nil
 		}
@@ -642,11 +654,11 @@ func (p *Parser) convertType(input gjson.Result, desiredType string, name string
 			} else if inputType == 1 {
 				return true, nil
 			} else {
-				return nil, fmt.Errorf("Unable to convert field '%s' to type bool", name)
+				return nil, fmt.Errorf("unable to convert field %q to type bool", name)
 			}
 		}
 	default:
-		return nil, fmt.Errorf("unknown format '%T' for field  '%s'", inputType, name)
+		return nil, fmt.Errorf("unknown format '%T' for field  %q", inputType, name)
 	}
 
 	return input.Value(), nil
