@@ -14,8 +14,6 @@ import (
 	"github.com/influxdata/telegraf/plugins/processors"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
-//
 //go:embed sample.conf
 var sampleConfig string
 
@@ -96,7 +94,7 @@ func (*Noise) SampleConfig() string {
 func (p *Noise) Init() error {
 	fieldFilter, err := filter.NewIncludeExcludeFilter(p.IncludeFields, p.ExcludeFields)
 	if err != nil {
-		return fmt.Errorf("creating fieldFilter failed: %v", err)
+		return fmt.Errorf("creating fieldFilter failed: %w", err)
 	}
 	p.fieldFilter = fieldFilter
 
