@@ -11,8 +11,6 @@ import (
 	"github.com/influxdata/telegraf/plugins/serializers/influx"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
-//
 //go:embed sample.conf
 var sampleConfig string
 
@@ -30,7 +28,7 @@ func (p *Printer) Apply(in ...telegraf.Metric) []telegraf.Metric {
 		if err != nil {
 			continue
 		}
-		fmt.Printf("%s", octets)
+		fmt.Print(octets)
 	}
 	return in
 }
