@@ -9,7 +9,6 @@ import (
 	"github.com/influxdata/telegraf/plugins/processors"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
 //go:embed sample.conf
 var sampleConfig string
 
@@ -53,13 +52,11 @@ func (d *TagLimit) Apply(in ...telegraf.Metric) []telegraf.Metric {
 		if lenPointTags <= d.Limit {
 			continue
 		}
-		tagsToRemove := make([]string, lenPointTags-d.Limit)
-		removeIdx := 0
+		tagsToRemove := make([]string, 0, lenPointTags-d.Limit)
 		// remove extraneous tags, stop once we're at the limit
 		for _, t := range pointOriginalTags {
 			if _, ok := d.keepTags[t.Key]; !ok {
-				tagsToRemove[removeIdx] = t.Key
-				removeIdx++
+				tagsToRemove = append(tagsToRemove, t.Key)
 				lenPointTags--
 			}
 			if lenPointTags <= d.Limit {
