@@ -3,18 +3,19 @@ package unpivot
 
 import (
 	_ "embed"
+	"fmt"
 
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/plugins/processors"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
 //go:embed sample.conf
 var sampleConfig string
 
 type Unpivot struct {
-	TagKey   string `toml:"tag_key"`
-	ValueKey string `toml:"value_key"`
+	FieldNameAs string `toml:"use_fieldname_as"`
+	TagKey      string `toml:"tag_key"`
+	ValueKey    string `toml:"value_key"`
 }
 
 func copyWithoutFields(metric telegraf.Metric) telegraf.Metric {
@@ -36,12 +37,30 @@ func (*Unpivot) SampleConfig() string {
 	return sampleConfig
 }
 
+func (p *Unpivot) Init() error {
+	switch p.FieldNameAs {
+	case "metric":
+	case "", "tag":
+		p.FieldNameAs = "tag"
+	default:
+		return fmt.Errorf("unrecognized metric mode: %q", p.FieldNameAs)
+	}
+
+	if p.TagKey == "" {
+		p.TagKey = "name"
+	}
+	if p.ValueKey == "" {
+		p.ValueKey = "value"
+	}
+
+	return nil
+}
+
 func (p *Unpivot) Apply(metrics ...telegraf.Metric) []telegraf.Metric {
 	fieldCount := 0
 	for _, m := range metrics {
 		fieldCount += len(m.FieldList())
 	}
-
 	results := make([]telegraf.Metric, 0, fieldCount)
 
 	for _, m := range metrics {
@@ -49,7 +68,14 @@ func (p *Unpivot) Apply(metrics ...telegraf.Metric) []telegraf.Metric {
 		for _, field := range m.FieldList() {
 			newMetric := base.Copy()
 			newMetric.AddField(p.ValueKey, field.Value)
-			newMetric.AddTag(p.TagKey, field.Key)
+
+			switch p.FieldNameAs {
+			case "metric":
+				newMetric.SetName(field.Key)
+			case "", "tag":
+				newMetric.AddTag(p.TagKey, field.Key)
+			}
+
 			results = append(results, newMetric)
 		}
 		m.Accept()
