@@ -26,7 +26,12 @@ func TestSerializeMetricFloat(t *testing.T) {
 	var buf []byte
 	buf, err := s.Serialize(m)
 	require.NoError(t, err)
-	expS := []byte(fmt.Sprintf(`[{"metric_type":"usage_idle","resource":"","node":"","value":91.5,"timestamp":%d,"ci2metric_id":null,"source":"Telegraf"}]`, now.UnixNano()/int64(time.Millisecond)))
+	expS := []byte(
+		fmt.Sprintf(
+			`[{"metric_type":"usage_idle","resource":"","node":"","value":91.5,"timestamp":%d,"ci2metric_id":null,"source":"Telegraf"}]`,
+			now.UnixNano()/int64(time.Millisecond),
+		),
+	)
 	require.Equal(t, string(expS), string(buf))
 }
 
@@ -90,7 +95,12 @@ func TestSerializeMetricInt(t *testing.T) {
 	buf, err := s.Serialize(m)
 	require.NoError(t, err)
 
-	expS := []byte(fmt.Sprintf(`[{"metric_type":"usage_idle","resource":"","node":"","value":90,"timestamp":%d,"ci2metric_id":null,"source":"Telegraf"}]`, now.UnixNano()/int64(time.Millisecond)))
+	expS := []byte(
+		fmt.Sprintf(
+			`[{"metric_type":"usage_idle","resource":"","node":"","value":90,"timestamp":%d,"ci2metric_id":null,"source":"Telegraf"}]`,
+			now.UnixNano()/int64(time.Millisecond),
+		),
+	)
 	require.Equal(t, string(expS), string(buf))
 }
 
@@ -133,7 +143,14 @@ func TestSerializeMultiFields(t *testing.T) {
 	buf, err := s.Serialize(m)
 	require.NoError(t, err)
 
-	expS := []byte(fmt.Sprintf(`[{"metric_type":"usage_idle","resource":"","node":"","value":90,"timestamp":%d,"ci2metric_id":null,"source":"Telegraf"},{"metric_type":"usage_total","resource":"","node":"","value":8559615,"timestamp":%d,"ci2metric_id":null,"source":"Telegraf"}]`, now.UnixNano()/int64(time.Millisecond), now.UnixNano()/int64(time.Millisecond)))
+	expS := []byte(
+		fmt.Sprintf(
+			`[{"metric_type":"usage_idle","resource":"","node":"","value":90,"timestamp":%d,"ci2metric_id":null,"source":"Telegraf"},`+
+				`{"metric_type":"usage_total","resource":"","node":"","value":8559615,"timestamp":%d,"ci2metric_id":null,"source":"Telegraf"}]`,
+			now.UnixNano()/int64(time.Millisecond),
+			now.UnixNano()/int64(time.Millisecond),
+		),
+	)
 	require.Equal(t, string(expS), string(buf))
 }
 
@@ -151,7 +168,12 @@ func TestSerializeMetricWithEscapes(t *testing.T) {
 	buf, err := s.Serialize(m)
 	require.NoError(t, err)
 
-	expS := []byte(fmt.Sprintf(`[{"metric_type":"U,age=Idle","resource":"","node":"","value":90,"timestamp":%d,"ci2metric_id":null,"source":"Telegraf"}]`, now.UnixNano()/int64(time.Millisecond)))
+	expS := []byte(
+		fmt.Sprintf(
+			`[{"metric_type":"U,age=Idle","resource":"","node":"","value":90,"timestamp":%d,"ci2metric_id":null,"source":"Telegraf"}]`,
+			now.UnixNano()/int64(time.Millisecond),
+		),
+	)
 	require.Equal(t, string(expS), string(buf))
 }
 
@@ -168,5 +190,12 @@ func TestSerializeBatch(t *testing.T) {
 	s, _ := NewSerializer()
 	buf, err := s.SerializeBatch(metrics)
 	require.NoError(t, err)
-	require.Equal(t, []byte(`[{"metric_type":"value","resource":"","node":"","value":42,"timestamp":0,"ci2metric_id":null,"source":"Telegraf"},{"metric_type":"value","resource":"","node":"","value":42,"timestamp":0,"ci2metric_id":null,"source":"Telegraf"}]`), buf)
+	require.Equal(
+		t,
+		[]byte(
+			`[{"metric_type":"value","resource":"","node":"","value":42,"timestamp":0,"ci2metric_id":null,"source":"Telegraf"},`+
+				`{"metric_type":"value","resource":"","node":"","value":42,"timestamp":0,"ci2metric_id":null,"source":"Telegraf"}]`,
+		),
+		buf,
+	)
 }
