@@ -87,10 +87,10 @@ type MetricKey uint64
 func MakeMetricKey(labels []LabelPair) MetricKey {
 	h := fnv.New64a()
 	for _, label := range labels {
-		h.Write([]byte(label.Name))  //nolint:revive // from hash.go: "It never returns an error"
-		h.Write([]byte("\x00"))      //nolint:revive // from hash.go: "It never returns an error"
-		h.Write([]byte(label.Value)) //nolint:revive // from hash.go: "It never returns an error"
-		h.Write([]byte("\x00"))      //nolint:revive // from hash.go: "It never returns an error"
+		h.Write([]byte(label.Name))
+		h.Write([]byte("\x00"))
+		h.Write([]byte(label.Value))
+		h.Write([]byte("\x00"))
 	}
 	return MetricKey(h.Sum64())
 }
@@ -412,10 +412,13 @@ func (c *Collection) GetProto() []*dto.MetricFamily {
 	for _, entry := range c.GetEntries(c.config.MetricSortOrder) {
 		mf := &dto.MetricFamily{
 			Name: proto.String(entry.Family.Name),
-			Help: proto.String(helpString),
 			Type: MetricType(entry.Family.Type),
 		}
 
+		if !c.config.CompactEncoding {
+			mf.Help = proto.String(helpString)
+		}
+
 		for _, metric := range c.GetMetrics(entry, c.config.MetricSortOrder) {
 			l := make([]*dto.LabelPair, 0, len(metric.Labels))
 			for _, label := range metric.Labels {
